@@ -6,18 +6,18 @@
 // Qt
 #include <QtTest>
 // KWin
+#include "../../src/server/compositor_interface.h"
+#include "../../src/server/display.h"
+#include "../../src/server/plasmavirtualdesktop_interface.h"
+#include "../../src/server/plasmawindowmanagement_interface.h"
 #include "KWayland/Client/compositor.h"
 #include "KWayland/Client/connection_thread.h"
 #include "KWayland/Client/event_queue.h"
+#include "KWayland/Client/plasmavirtualdesktop.h"
+#include "KWayland/Client/plasmawindowmanagement.h"
 #include "KWayland/Client/region.h"
 #include "KWayland/Client/registry.h"
 #include "KWayland/Client/surface.h"
-#include "KWayland/Client/plasmavirtualdesktop.h"
-#include "../../src/server/display.h"
-#include "../../src/server/compositor_interface.h"
-#include "../../src/server/plasmavirtualdesktop_interface.h"
-#include "../../src/server/plasmawindowmanagement_interface.h"
-#include "KWayland/Client/plasmawindowmanagement.h"
 
 using namespace KWayland::Client;
 
@@ -122,13 +122,16 @@ void TestVirtualDesktop::init()
     m_plasmaVirtualDesktopManagementInterface = new PlasmaVirtualDesktopManagementInterface(m_display, m_display);
 
     QVERIFY(plasmaVirtualDesktopManagementSpy.wait());
-    m_plasmaVirtualDesktopManagement = registry.createPlasmaVirtualDesktopManagement(plasmaVirtualDesktopManagementSpy.first().first().value<quint32>(), plasmaVirtualDesktopManagementSpy.first().last().value<quint32>(), this);
+    m_plasmaVirtualDesktopManagement = registry.createPlasmaVirtualDesktopManagement(plasmaVirtualDesktopManagementSpy.first().first().value<quint32>(),
+                                                                                     plasmaVirtualDesktopManagementSpy.first().last().value<quint32>(),
+                                                                                     this);
 
     m_windowManagementInterface = new PlasmaWindowManagementInterface(m_display, m_display);
     m_windowManagementInterface->setPlasmaVirtualDesktopManagementInterface(m_plasmaVirtualDesktopManagementInterface);
 
     QVERIFY(windowManagementSpy.wait());
-    m_windowManagement = registry.createPlasmaWindowManagement(windowManagementSpy.first().first().value<quint32>(), windowManagementSpy.first().last().value<quint32>(), this);
+    m_windowManagement =
+        registry.createPlasmaWindowManagement(windowManagementSpy.first().first().value<quint32>(), windowManagementSpy.first().last().value<quint32>(), this);
 
     QSignalSpy windowSpy(m_windowManagement, &PlasmaWindowManagement::windowCreated);
     QVERIFY(windowSpy.isValid());
@@ -141,10 +144,10 @@ void TestVirtualDesktop::init()
 
 void TestVirtualDesktop::cleanup()
 {
-#define CLEANUP(variable) \
-    if (variable) { \
-        delete variable; \
-        variable = nullptr; \
+#define CLEANUP(variable)                                                                                                                                      \
+    if (variable) {                                                                                                                                            \
+        delete variable;                                                                                                                                       \
+        variable = nullptr;                                                                                                                                    \
     }
     CLEANUP(m_compositor)
     CLEANUP(m_plasmaVirtualDesktopManagement)
@@ -173,8 +176,7 @@ void TestVirtualDesktop::testCreate()
     QSignalSpy desktopCreatedSpy(m_plasmaVirtualDesktopManagement, &PlasmaVirtualDesktopManagement::desktopCreated);
     QSignalSpy managementDoneSpy(m_plasmaVirtualDesktopManagement, &PlasmaVirtualDesktopManagement::done);
 
-
-    //on this createDesktop bind() isn't called already, the desktopadded signals will be sent after bind happened
+    // on this createDesktop bind() isn't called already, the desktopadded signals will be sent after bind happened
     KWaylandServer::PlasmaVirtualDesktopInterface *desktop1Int = m_plasmaVirtualDesktopManagementInterface->createDesktop(QStringLiteral("0-1"));
     desktop1Int->setName("Desktop 1");
 
@@ -185,7 +187,6 @@ void TestVirtualDesktop::testCreate()
     m_plasmaVirtualDesktopManagementInterface->sendDone();
     managementDoneSpy.wait();
 
-
     QCOMPARE(m_plasmaVirtualDesktopManagement->desktops().length(), 1);
 
     KWayland::Client::PlasmaVirtualDesktop *desktop1 = m_plasmaVirtualDesktopManagement->desktops().first();
@@ -196,8 +197,7 @@ void TestVirtualDesktop::testCreate()
     QCOMPARE(desktop1->id(), QStringLiteral("0-1"));
     QCOMPARE(desktop1->name(), QStringLiteral("Desktop 1"));
 
-
-    //on those createDesktop the bind will already be done
+    // on those createDesktop the bind will already be done
     KWaylandServer::PlasmaVirtualDesktopInterface *desktop2Int = m_plasmaVirtualDesktopManagementInterface->createDesktop(QStringLiteral("0-2"));
     desktop2Int->setName("Desktop 2");
     desktopCreatedSpy.wait();
@@ -216,8 +216,7 @@ void TestVirtualDesktop::testCreate()
     m_plasmaVirtualDesktopManagementInterface->sendDone();
     managementDoneSpy.wait();
 
-
-    //get the clients
+    // get the clients
     KWayland::Client::PlasmaVirtualDesktop *desktop2 = m_plasmaVirtualDesktopManagement->desktops()[1];
     QSignalSpy desktop2DoneSpy(desktop2, &PlasmaVirtualDesktop::done);
     desktop2Int->sendDone();
@@ -228,7 +227,6 @@ void TestVirtualDesktop::testCreate()
     desktop3Int->sendDone();
     desktop3DoneSpy.wait();
 
-
     QCOMPARE(desktop1->id(), QStringLiteral("0-1"));
     QCOMPARE(desktop1->name(), QStringLiteral("Desktop 1"));
 
@@ -238,7 +236,7 @@ void TestVirtualDesktop::testCreate()
     QCOMPARE(desktop3->id(), QStringLiteral("0-3"));
     QCOMPARE(desktop3->name(), QStringLiteral("Desktop 3"));
 
-    //coherence of order between client and server
+    // coherence of order between client and server
     QCOMPARE(m_plasmaVirtualDesktopManagementInterface->desktops().length(), 3);
     QCOMPARE(m_plasmaVirtualDesktopManagement->desktops().length(), 3);
 
@@ -249,7 +247,7 @@ void TestVirtualDesktop::testCreate()
 
 void TestVirtualDesktop::testSetRows()
 {
-    //rebuild some desktops
+    // rebuild some desktops
     testCreate();
 
     QSignalSpy rowsChangedSpy(m_plasmaVirtualDesktopManagement, &PlasmaVirtualDesktopManagement::rowsChanged);
@@ -261,7 +259,7 @@ void TestVirtualDesktop::testSetRows()
 
 void TestVirtualDesktop::testConnectNewClient()
 {
-    //rebuild some desktops
+    // rebuild some desktops
     testCreate();
 
     Registry registry;
@@ -277,7 +275,10 @@ void TestVirtualDesktop::testConnectNewClient()
 
     QVERIFY(plasmaVirtualDesktopManagementSpy.wait());
 
-    KWayland::Client::PlasmaVirtualDesktopManagement *otherPlasmaVirtualDesktopManagement = registry.createPlasmaVirtualDesktopManagement(plasmaVirtualDesktopManagementSpy.first().first().value<quint32>(), plasmaVirtualDesktopManagementSpy.first().last().value<quint32>(), this);
+    KWayland::Client::PlasmaVirtualDesktopManagement *otherPlasmaVirtualDesktopManagement =
+        registry.createPlasmaVirtualDesktopManagement(plasmaVirtualDesktopManagementSpy.first().first().value<quint32>(),
+                                                      plasmaVirtualDesktopManagementSpy.first().last().value<quint32>(),
+                                                      this);
 
     QSignalSpy managementDoneSpy(otherPlasmaVirtualDesktopManagement, &PlasmaVirtualDesktopManagement::done);
 
@@ -289,24 +290,23 @@ void TestVirtualDesktop::testConnectNewClient()
 
 void TestVirtualDesktop::testDestroy()
 {
-    //rebuild some desktops
+    // rebuild some desktops
     testCreate();
 
     KWaylandServer::PlasmaVirtualDesktopInterface *desktop1Int = m_plasmaVirtualDesktopManagementInterface->desktops().first();
     KWayland::Client::PlasmaVirtualDesktop *desktop1 = m_plasmaVirtualDesktopManagement->desktops().first();
 
-
     QSignalSpy desktop1IntDestroyedSpy(desktop1Int, &QObject::destroyed);
     QSignalSpy desktop1DestroyedSpy(desktop1, &QObject::destroyed);
     QSignalSpy desktop1RemovedSpy(desktop1, &KWayland::Client::PlasmaVirtualDesktop::removed);
     m_plasmaVirtualDesktopManagementInterface->removeDesktop(QStringLiteral("0-1"));
 
-    //test that both server and client desktoip interfaces go away
+    // test that both server and client desktoip interfaces go away
     desktop1IntDestroyedSpy.wait();
     desktop1RemovedSpy.wait();
     desktop1DestroyedSpy.wait();
 
-    //coherence of order between client and server
+    // coherence of order between client and server
     QCOMPARE(m_plasmaVirtualDesktopManagementInterface->desktops().length(), 2);
     QCOMPARE(m_plasmaVirtualDesktopManagement->desktops().length(), 2);
 
@@ -314,7 +314,7 @@ void TestVirtualDesktop::testDestroy()
         QCOMPARE(m_plasmaVirtualDesktopManagementInterface->desktops().at(i)->id(), m_plasmaVirtualDesktopManagement->desktops().at(i)->id());
     }
 
-    //Test the desktopRemoved signal of the manager, remove another desktop as the signals can't be tested at the same time
+    // Test the desktopRemoved signal of the manager, remove another desktop as the signals can't be tested at the same time
     QSignalSpy desktopManagerRemovedSpy(m_plasmaVirtualDesktopManagement, &KWayland::Client::PlasmaVirtualDesktopManagement::desktopRemoved);
     m_plasmaVirtualDesktopManagementInterface->removeDesktop(QStringLiteral("0-2"));
     desktopManagerRemovedSpy.wait();
@@ -326,7 +326,7 @@ void TestVirtualDesktop::testDestroy()
 
 void TestVirtualDesktop::testActivate()
 {
-    //rebuild some desktops
+    // rebuild some desktops
     testCreate();
 
     KWaylandServer::PlasmaVirtualDesktopInterface *desktop1Int = m_plasmaVirtualDesktopManagementInterface->desktops().first();
@@ -344,7 +344,7 @@ void TestVirtualDesktop::testActivate()
     desktop2->requestActivate();
     requestActivateSpy.wait();
 
-    //This simulates a compositor which supports only one active desktop at a time
+    // This simulates a compositor which supports only one active desktop at a time
     for (auto *deskInt : m_plasmaVirtualDesktopManagementInterface->desktops()) {
         if (deskInt->id() == desktop2->id()) {
             deskInt->setActive(true);
@@ -354,14 +354,14 @@ void TestVirtualDesktop::testActivate()
     }
     activatedSpy.wait();
 
-    //correct state in the server
+    // correct state in the server
     QVERIFY(desktop2Int->isActive());
     QVERIFY(!desktop1Int->isActive());
-    //correct state in the client
+    // correct state in the client
     QVERIFY(desktop2Int->isActive());
     QVERIFY(!desktop1Int->isActive());
 
-    //Test the deactivated signal
+    // Test the deactivated signal
     QSignalSpy deactivatedSpy(desktop2, &KWayland::Client::PlasmaVirtualDesktop::deactivated);
 
     for (auto *deskInt : m_plasmaVirtualDesktopManagementInterface->desktops()) {
@@ -386,18 +386,18 @@ void TestVirtualDesktop::testEnterLeaveDesktop()
 
     QSignalSpy virtualDesktopEnteredSpy(m_window, &KWayland::Client::PlasmaWindow::plasmaVirtualDesktopEntered);
 
-    //agree to the request
+    // agree to the request
     m_windowInterface->addPlasmaVirtualDesktop(QStringLiteral("0-1"));
     QCOMPARE(m_windowInterface->plasmaVirtualDesktops().length(), 1);
     QCOMPARE(m_windowInterface->plasmaVirtualDesktops().first(), QStringLiteral("0-1"));
 
-    //check if the client received the enter
+    // check if the client received the enter
     virtualDesktopEnteredSpy.wait();
     QCOMPARE(virtualDesktopEnteredSpy.takeFirst().at(0).toString(), QStringLiteral("0-1"));
     QCOMPARE(m_window->plasmaVirtualDesktops().length(), 1);
     QCOMPARE(m_window->plasmaVirtualDesktops().first(), QStringLiteral("0-1"));
 
-    //add another desktop, server side
+    // add another desktop, server side
     m_windowInterface->addPlasmaVirtualDesktop(QStringLiteral("0-3"));
     virtualDesktopEnteredSpy.wait();
     QCOMPARE(virtualDesktopEnteredSpy.takeFirst().at(0).toString(), QStringLiteral("0-3"));
@@ -405,13 +405,11 @@ void TestVirtualDesktop::testEnterLeaveDesktop()
     QCOMPARE(m_window->plasmaVirtualDesktops().length(), 2);
     QCOMPARE(m_window->plasmaVirtualDesktops()[1], QStringLiteral("0-3"));
 
-
-
-    //try to add an invalid desktop
+    // try to add an invalid desktop
     m_windowInterface->addPlasmaVirtualDesktop(QStringLiteral("invalid"));
     QCOMPARE(m_window->plasmaVirtualDesktops().length(), 2);
 
-    //remove a desktop
+    // remove a desktop
     QSignalSpy leaveRequestedSpy(m_windowInterface, &KWaylandServer::PlasmaWindowInterface::leavePlasmaVirtualDesktopRequested);
     m_window->requestLeaveVirtualDesktop(QStringLiteral("0-1"));
     leaveRequestedSpy.wait();
@@ -420,20 +418,20 @@ void TestVirtualDesktop::testEnterLeaveDesktop()
 
     QSignalSpy virtualDesktopLeftSpy(m_window, &KWayland::Client::PlasmaWindow::plasmaVirtualDesktopLeft);
 
-    //agree to the request
+    // agree to the request
     m_windowInterface->removePlasmaVirtualDesktop(QStringLiteral("0-1"));
     QCOMPARE(m_windowInterface->plasmaVirtualDesktops().length(), 1);
     QCOMPARE(m_windowInterface->plasmaVirtualDesktops().first(), QStringLiteral("0-3"));
 
-    //check if the client received the leave
+    // check if the client received the leave
     virtualDesktopLeftSpy.wait();
     QCOMPARE(virtualDesktopLeftSpy.takeFirst().at(0).toString(), QStringLiteral("0-1"));
     QCOMPARE(m_window->plasmaVirtualDesktops().length(), 1);
     QCOMPARE(m_window->plasmaVirtualDesktops().first(), QStringLiteral("0-3"));
 
-    //Destroy desktop 2
+    // Destroy desktop 2
     m_plasmaVirtualDesktopManagementInterface->removeDesktop(QStringLiteral("0-3"));
-    //the window should receive a left signal from the destroyed desktop
+    // the window should receive a left signal from the destroyed desktop
     virtualDesktopLeftSpy.wait();
 
     QCOMPARE(m_window->plasmaVirtualDesktops().length(), 0);
@@ -445,15 +443,15 @@ void TestVirtualDesktop::testAllDesktops()
     QSignalSpy virtualDesktopEnteredSpy(m_window, &KWayland::Client::PlasmaWindow::plasmaVirtualDesktopEntered);
     QSignalSpy virtualDesktopLeftSpy(m_window, &KWayland::Client::PlasmaWindow::plasmaVirtualDesktopLeft);
 
-    //in the beginning the window is on desktop 1 and desktop 3
+    // in the beginning the window is on desktop 1 and desktop 3
     m_windowInterface->addPlasmaVirtualDesktop(QStringLiteral("0-1"));
     m_windowInterface->addPlasmaVirtualDesktop(QStringLiteral("0-3"));
     virtualDesktopEnteredSpy.wait();
 
-    //setting on all desktops
+    // setting on all desktops
     QCOMPARE(m_window->plasmaVirtualDesktops().length(), 2);
     m_windowInterface->setOnAllDesktops(true);
-    //setting on all desktops, the window will leave every desktop
+    // setting on all desktops, the window will leave every desktop
 
     virtualDesktopLeftSpy.wait();
     QCOMPARE(virtualDesktopLeftSpy.count(), 2);
@@ -463,7 +461,7 @@ void TestVirtualDesktop::testAllDesktops()
     QCOMPARE(m_window->plasmaVirtualDesktops().length(), 0);
     QVERIFY(m_window->isOnAllDesktops());
 
-    //return to the active desktop (0-1)
+    // return to the active desktop (0-1)
     m_windowInterface->setOnAllDesktops(false);
     virtualDesktopEnteredSpy.wait();
     QCOMPARE(m_window->plasmaVirtualDesktops().length(), 1);
@@ -473,19 +471,20 @@ void TestVirtualDesktop::testAllDesktops()
 
 void TestVirtualDesktop::testCreateRequested()
 {
-    //rebuild some desktops
+    // rebuild some desktops
     testCreate();
 
-    QSignalSpy desktopCreateRequestedSpy(m_plasmaVirtualDesktopManagementInterface, &KWaylandServer::PlasmaVirtualDesktopManagementInterface::desktopCreateRequested);
+    QSignalSpy desktopCreateRequestedSpy(m_plasmaVirtualDesktopManagementInterface,
+                                         &KWaylandServer::PlasmaVirtualDesktopManagementInterface::desktopCreateRequested);
     QSignalSpy desktopCreatedSpy(m_plasmaVirtualDesktopManagement, &PlasmaVirtualDesktopManagement::desktopCreated);
 
-    //listen for createdRequested
+    // listen for createdRequested
     m_plasmaVirtualDesktopManagement->requestCreateVirtualDesktop(QStringLiteral("Desktop"), 1);
     desktopCreateRequestedSpy.wait();
     QCOMPARE(desktopCreateRequestedSpy.first().first().toString(), QStringLiteral("Desktop"));
     QCOMPARE(desktopCreateRequestedSpy.first().at(1).toUInt(), (quint32)1);
 
-    //actually create
+    // actually create
     m_plasmaVirtualDesktopManagementInterface->createDesktop(QStringLiteral("0-4"), 1);
     KWaylandServer::PlasmaVirtualDesktopInterface *desktopInt = m_plasmaVirtualDesktopManagementInterface->desktops().at(1);
 
@@ -500,8 +499,8 @@ void TestVirtualDesktop::testCreateRequested()
     PlasmaVirtualDesktop *desktop = m_plasmaVirtualDesktopManagement->desktops().at(1);
     QSignalSpy desktopDoneSpy(desktop, &PlasmaVirtualDesktop::done);
     desktopInt->sendDone();
-   // desktopDoneSpy.wait();
-    //check the order is correct
+    // desktopDoneSpy.wait();
+    // check the order is correct
     QCOMPARE(m_plasmaVirtualDesktopManagement->desktops().at(0)->id(), QStringLiteral("0-1"));
     QCOMPARE(desktop->id(), QStringLiteral("0-4"));
     QCOMPARE(m_plasmaVirtualDesktopManagement->desktops().at(2)->id(), QStringLiteral("0-2"));
@@ -510,12 +509,13 @@ void TestVirtualDesktop::testCreateRequested()
 
 void TestVirtualDesktop::testRemoveRequested()
 {
-    //rebuild some desktops
+    // rebuild some desktops
     testCreate();
 
-    QSignalSpy desktopRemoveRequestedSpy(m_plasmaVirtualDesktopManagementInterface, &KWaylandServer::PlasmaVirtualDesktopManagementInterface::desktopRemoveRequested);
+    QSignalSpy desktopRemoveRequestedSpy(m_plasmaVirtualDesktopManagementInterface,
+                                         &KWaylandServer::PlasmaVirtualDesktopManagementInterface::desktopRemoveRequested);
 
-    //request a remove, just check the request arrived, ignore the request.
+    // request a remove, just check the request arrived, ignore the request.
     m_plasmaVirtualDesktopManagement->requestRemoveVirtualDesktop(QStringLiteral("0-1"));
     desktopRemoveRequestedSpy.wait();
     QCOMPARE(desktopRemoveRequestedSpy.first().first().toString(), QStringLiteral("0-1"));
