@@ -6,21 +6,19 @@
 // Qt
 #include <QtTest>
 // KWayland
-#include "KWayland/Client/connection_thread.h"
+#include "../../src/server/compositor_interface.h"
+#include "../../src/server/display.h"
+#include "../../src/server/plasmashell_interface.h"
 #include "KWayland/Client/compositor.h"
+#include "KWayland/Client/connection_thread.h"
 #include "KWayland/Client/event_queue.h"
+#include "KWayland/Client/plasmashell.h"
 #include "KWayland/Client/registry.h"
 #include "KWayland/Client/surface.h"
-#include "KWayland/Client/plasmashell.h"
-#include "../../src/server/display.h"
-#include "../../src/server/compositor_interface.h"
-#include "../../src/server/plasmashell_interface.h"
-
 
 using namespace KWayland::Client;
 using namespace KWaylandServer;
 
-
 class TestPlasmaShell : public QObject
 {
     Q_OBJECT
@@ -28,7 +26,6 @@ private Q_SLOTS:
     void init();
     void cleanup();
 
-
     void testRole_data();
     void testRole();
     void testPosition();
@@ -99,23 +96,23 @@ void TestPlasmaShell::init()
     m_registry->setup();
 
     QVERIFY(interfacesAnnouncedSpy.wait());
-#define CREATE(variable, factory, iface) \
-    variable = m_registry->create##factory(m_registry->interface(Registry::Interface::iface).name, m_registry->interface(Registry::Interface::iface).version, this); \
+#define CREATE(variable, factory, iface)                                                                                                                       \
+    variable =                                                                                                                                                 \
+        m_registry->create##factory(m_registry->interface(Registry::Interface::iface).name, m_registry->interface(Registry::Interface::iface).version, this);  \
     QVERIFY(variable);
 
     CREATE(m_compositor, Compositor, Compositor)
     CREATE(m_plasmaShell, PlasmaShell, PlasmaShell)
 
 #undef CREATE
-
 }
 
 void TestPlasmaShell::cleanup()
 {
-#define DELETE(name) \
-    if (name) { \
-        delete name; \
-        name = nullptr; \
+#define DELETE(name)                                                                                                                                           \
+    if (name) {                                                                                                                                                \
+        delete name;                                                                                                                                           \
+        name = nullptr;                                                                                                                                        \
     }
     DELETE(m_plasmaShell)
     DELETE(m_compositor)
@@ -176,10 +173,10 @@ void TestPlasmaShell::testRole()
     QCOMPARE(surfaceCreatedSpy.count(), 1);
 
     // verify that we got a plasma shell surface
-    auto sps = plasmaSurfaceCreatedSpy.first().first().value<PlasmaShellSurfaceInterface*>();
+    auto sps = plasmaSurfaceCreatedSpy.first().first().value<PlasmaShellSurfaceInterface *>();
     QVERIFY(sps);
     QVERIFY(sps->surface());
-    QCOMPARE(sps->surface(), surfaceCreatedSpy.first().first().value<SurfaceInterface*>());
+    QCOMPARE(sps->surface(), surfaceCreatedSpy.first().first().value<SurfaceInterface *>());
 
     // default role should be normal
     QCOMPARE(sps->role(), PlasmaShellSurfaceInterface::Role::Normal);
@@ -218,7 +215,7 @@ void TestPlasmaShell::testPosition()
     QCOMPARE(plasmaSurfaceCreatedSpy.count(), 1);
 
     // verify that we got a plasma shell surface
-    auto sps = plasmaSurfaceCreatedSpy.first().first().value<PlasmaShellSurfaceInterface*>();
+    auto sps = plasmaSurfaceCreatedSpy.first().first().value<PlasmaShellSurfaceInterface *>();
     QVERIFY(sps);
     QVERIFY(sps->surface());
 
@@ -257,7 +254,7 @@ void TestPlasmaShell::testSkipTaskbar()
     QCOMPARE(plasmaSurfaceCreatedSpy.count(), 1);
 
     // verify that we got a plasma shell surface
-    auto sps = plasmaSurfaceCreatedSpy.first().first().value<PlasmaShellSurfaceInterface*>();
+    auto sps = plasmaSurfaceCreatedSpy.first().first().value<PlasmaShellSurfaceInterface *>();
     QVERIFY(sps);
     QVERIFY(sps->surface());
     QVERIFY(!sps->skipTaskbar());
@@ -292,7 +289,7 @@ void TestPlasmaShell::testSkipSwitcher()
     QCOMPARE(plasmaSurfaceCreatedSpy.count(), 1);
 
     // verify that we got a plasma shell surface
-    auto sps = plasmaSurfaceCreatedSpy.first().first().value<PlasmaShellSurfaceInterface*>();
+    auto sps = plasmaSurfaceCreatedSpy.first().first().value<PlasmaShellSurfaceInterface *>();
     QVERIFY(sps);
     QVERIFY(sps->surface());
     QVERIFY(!sps->skipSwitcher());
@@ -338,7 +335,7 @@ void TestPlasmaShell::testPanelBehavior()
     QCOMPARE(plasmaSurfaceCreatedSpy.count(), 1);
 
     // verify that we got a plasma shell surface
-    auto sps = plasmaSurfaceCreatedSpy.first().first().value<PlasmaShellSurfaceInterface*>();
+    auto sps = plasmaSurfaceCreatedSpy.first().first().value<PlasmaShellSurfaceInterface *>();
     QVERIFY(sps);
     QVERIFY(sps->surface());
     QCOMPARE(sps->panelBehavior(), PlasmaShellSurfaceInterface::PanelBehavior::AlwaysVisible);
@@ -373,7 +370,7 @@ void TestPlasmaShell::testAutoHidePanel()
     ps->setPanelBehavior(PlasmaShellSurface::PanelBehavior::AutoHide);
     QVERIFY(plasmaSurfaceCreatedSpy.wait());
     QCOMPARE(plasmaSurfaceCreatedSpy.count(), 1);
-    auto sps = plasmaSurfaceCreatedSpy.first().first().value<PlasmaShellSurfaceInterface*>();
+    auto sps = plasmaSurfaceCreatedSpy.first().first().value<PlasmaShellSurfaceInterface *>();
     QVERIFY(sps);
     QCOMPARE(sps->panelBehavior(), PlasmaShellSurfaceInterface::PanelBehavior::AutoHide);
 
@@ -426,7 +423,7 @@ void TestPlasmaShell::testPanelTakesFocus()
     ps->setRole(PlasmaShellSurface::Role::Panel);
     QVERIFY(plasmaSurfaceCreatedSpy.wait());
     QCOMPARE(plasmaSurfaceCreatedSpy.count(), 1);
-    auto sps = plasmaSurfaceCreatedSpy.first().first().value<PlasmaShellSurfaceInterface*>();
+    auto sps = plasmaSurfaceCreatedSpy.first().first().value<PlasmaShellSurfaceInterface *>();
     QSignalSpy plasmaSurfaceTakesFocusSpy(sps, &PlasmaShellSurfaceInterface::panelTakesFocusChanged);
 
     QVERIFY(sps);
@@ -457,7 +454,7 @@ void TestPlasmaShell::testDisconnect()
     // and get them on the server
     QVERIFY(plasmaSurfaceCreatedSpy.wait());
     QCOMPARE(plasmaSurfaceCreatedSpy.count(), 1);
-    auto sps = plasmaSurfaceCreatedSpy.first().first().value<PlasmaShellSurfaceInterface*>();
+    auto sps = plasmaSurfaceCreatedSpy.first().first().value<PlasmaShellSurfaceInterface *>();
     QVERIFY(sps);
 
     // disconnect
@@ -488,7 +485,7 @@ void TestPlasmaShell::testWhileDestroying()
     QVERIFY(surfaceCreatedSpy.isValid());
     QScopedPointer<Surface> s(m_compositor->createSurface());
     QVERIFY(surfaceCreatedSpy.wait());
-    auto serverSurface = surfaceCreatedSpy.first().first().value<SurfaceInterface*>();
+    auto serverSurface = surfaceCreatedSpy.first().first().value<SurfaceInterface *>();
     QVERIFY(serverSurface);
 
     // create ShellSurface
