@@ -4,24 +4,25 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 // Qt
-#include <QtTest>
 #include <QImage>
 #include <QPainter>
+#include <QtTest>
 // KWin
+#include "../../src/server/clientbuffer.h"
+#include "../../src/server/compositor_interface.h"
+#include "../../src/server/display.h"
+#include "../../src/server/idleinhibit_v1_interface.h"
+#include "../../src/server/shmclientbuffer.h"
+#include "../../src/server/surface_interface.h"
 #include "KWayland/Client/compositor.h"
 #include "KWayland/Client/connection_thread.h"
 #include "KWayland/Client/event_queue.h"
 #include "KWayland/Client/idleinhibit.h"
 #include "KWayland/Client/output.h"
-#include "KWayland/Client/surface.h"
 #include "KWayland/Client/region.h"
 #include "KWayland/Client/registry.h"
 #include "KWayland/Client/shm_pool.h"
-#include "../../src/server/buffer_interface.h"
-#include "../../src/server/compositor_interface.h"
-#include "../../src/server/display.h"
-#include "../../src/server/idleinhibit_v1_interface.h"
-#include "../../src/server/surface_interface.h"
+#include "KWayland/Client/surface.h"
 // Wayland
 #include <wayland-client-protocol.h>
 
@@ -137,7 +138,9 @@ void TestWaylandSurface::init()
     m_shm = registry.createShmPool(shmSpy.first().first().value<quint32>(), shmSpy.first().last().value<quint32>(), this);
     QVERIFY(m_shm->isValid());
 
-    m_idleInhibitManager = registry.createIdleInhibitManager(registry.interface(Registry::Interface::IdleInhibitManagerUnstableV1).name, registry.interface(Registry::Interface::IdleInhibitManagerUnstableV1).version, this);
+    m_idleInhibitManager = registry.createIdleInhibitManager(registry.interface(Registry::Interface::IdleInhibitManagerUnstableV1).name,
+                                                             registry.interface(Registry::Interface::IdleInhibitManagerUnstableV1).version,
+                                                             this);
     QVERIFY(m_idleInhibitManager->isValid());
 }
 
@@ -190,7 +193,7 @@ void TestWaylandSurface::testStaticAccessor()
     QCOMPARE(KWayland::Client::Surface::all().first(), s1);
     QCOMPARE(KWayland::Client::Surface::get(*s1), s1);
     QVERIFY(serverSurfaceCreated.wait());
-    auto serverSurface1 = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface*>();
+    auto serverSurface1 = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface *>();
     QVERIFY(serverSurface1);
     QCOMPARE(KWaylandServer::SurfaceInterface::get(serverSurface1->resource()), serverSurface1);
     QCOMPARE(KWaylandServer::SurfaceInterface::get(serverSurface1->id(), serverSurface1->client()), serverSurface1);
@@ -214,7 +217,7 @@ void TestWaylandSurface::testStaticAccessor()
     QCOMPARE(KWayland::Client::Surface::get(*s2), s2);
     serverSurfaceCreated.clear();
     QVERIFY(serverSurfaceCreated.wait());
-    auto serverSurface2 = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface*>();
+    auto serverSurface2 = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface *>();
     QVERIFY(serverSurface2);
     QCOMPARE(KWaylandServer::SurfaceInterface::get(serverSurface1->resource()), serverSurface1);
     QCOMPARE(KWaylandServer::SurfaceInterface::get(serverSurface1->id(), serverSurface1->client()), serverSurface1);
@@ -249,7 +252,7 @@ void TestWaylandSurface::testDamage()
     KWayland::Client::Surface *s = m_compositor->createSurface();
     s->setScale(2);
     QVERIFY(serverSurfaceCreated.wait());
-    KWaylandServer::SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface*>();
+    KWaylandServer::SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface *>();
     QVERIFY(serverSurface);
     QCOMPARE(serverSurface->damage(), QRegion());
     QVERIFY(!serverSurface->isMapped());
@@ -337,7 +340,7 @@ void TestWaylandSurface::testFrameCallback()
     QVERIFY(serverSurfaceCreated.isValid());
     KWayland::Client::Surface *s = m_compositor->createSurface();
     QVERIFY(serverSurfaceCreated.wait());
-    KWaylandServer::SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface*>();
+    KWaylandServer::SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface *>();
     QVERIFY(serverSurface);
 
     QSignalSpy damageSpy(serverSurface, &KWaylandServer::SurfaceInterface::damaged);
@@ -365,13 +368,13 @@ void TestWaylandSurface::testAttachBuffer()
     QVERIFY(serverSurfaceCreated.isValid());
     KWayland::Client::Surface *s = m_compositor->createSurface();
     QVERIFY(serverSurfaceCreated.wait());
-    KWaylandServer::SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface*>();
+    KWaylandServer::SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface *>();
     QVERIFY(serverSurface);
 
     // create three images
     QImage black(24, 24, QImage::Format_RGB32);
     black.fill(Qt::black);
-    QImage red(24, 24, QImage::Format_ARGB32); //Note - deliberately not premultiplied
+    QImage red(24, 24, QImage::Format_ARGB32); // Note - deliberately not premultiplied
     red.fill(QColor(255, 0, 0, 128));
     QImage blue(24, 24, QImage::Format_ARGB32_Premultiplied);
     blue.fill(QColor(0, 0, 255, 128));
@@ -405,11 +408,13 @@ void TestWaylandSurface::testAttachBuffer()
     QVERIFY(unmappedSpy.isEmpty());
 
     // now the ServerSurface should have the black image attached as a buffer
-    KWaylandServer::BufferInterface *buffer = serverSurface->buffer();
+    KWaylandServer::ClientBuffer *buffer = serverSurface->buffer();
     buffer->ref();
-    QVERIFY(buffer->shmBuffer());
-    QCOMPARE(buffer->data(), black);
-    QCOMPARE(buffer->data().format(), QImage::Format_RGB32);
+    auto shmBuffer = qobject_cast<KWaylandServer::ShmClientBuffer *>(buffer);
+    QVERIFY(shmBuffer);
+    QCOMPARE(shmBuffer->data(), black);
+    QCOMPARE(shmBuffer->data().format(), QImage::Format_RGB32);
+    QCOMPARE(shmBuffer->size(), QSize(24, 24));
 
     // render another frame
     s->attachBuffer(redBuffer);
@@ -419,16 +424,16 @@ void TestWaylandSurface::testAttachBuffer()
     QVERIFY(damageSpy.wait());
     QCOMPARE(mappedSpy.count(), 1);
     QVERIFY(unmappedSpy.isEmpty());
-    KWaylandServer::BufferInterface *buffer2 = serverSurface->buffer();
+    KWaylandServer::ClientBuffer *buffer2 = serverSurface->buffer();
     buffer2->ref();
-    QVERIFY(buffer2->shmBuffer());
-    QCOMPARE(buffer2->data().format(), QImage::Format_ARGB32_Premultiplied);
-    QCOMPARE(buffer2->data().width(), 24);
-    QCOMPARE(buffer2->data().height(), 24);
+    auto shmBuffer2 = qobject_cast<KWaylandServer::ShmClientBuffer *>(buffer2);
+    QVERIFY(shmBuffer2);
+    QCOMPARE(shmBuffer2->data().format(), QImage::Format_ARGB32_Premultiplied);
+    QCOMPARE(shmBuffer2->size(), QSize(24, 24));
     for (int i = 0; i < 24; ++i) {
         for (int j = 0; j < 24; ++j) {
             // it's premultiplied in the format
-            QCOMPARE(buffer2->data().pixel(i, j), qRgba(128, 0, 0, 128));
+            QCOMPARE(shmBuffer2->data().pixel(i, j), qRgba(128, 0, 0, 128));
         }
     }
     buffer2->unref();
@@ -448,7 +453,6 @@ void TestWaylandSurface::testAttachBuffer()
     QCOMPARE(mappedSpy.count(), 1);
     QVERIFY(unmappedSpy.isEmpty());
     QVERIFY(!buffer2->isReferenced());
-    delete buffer2;
     // TODO: we should have a signal on when the Buffer gets released
     QCoreApplication::processEvents(QEventLoop::WaitForMoreEvents);
     if (!redBuffer.data()->isReleased()) {
@@ -456,16 +460,16 @@ void TestWaylandSurface::testAttachBuffer()
     }
     QVERIFY(redBuffer.data()->isReleased());
 
-    KWaylandServer::BufferInterface *buffer3 = serverSurface->buffer();
+    KWaylandServer::ClientBuffer *buffer3 = serverSurface->buffer();
     buffer3->ref();
-    QVERIFY(buffer3->shmBuffer());
-    QCOMPARE(buffer3->data().format(), QImage::Format_ARGB32_Premultiplied);
-    QCOMPARE(buffer3->data().width(), 24);
-    QCOMPARE(buffer3->data().height(), 24);
+    auto shmBuffer3 = qobject_cast<KWaylandServer::ShmClientBuffer *>(buffer3);
+    QVERIFY(shmBuffer3);
+    QCOMPARE(shmBuffer3->data().format(), QImage::Format_ARGB32_Premultiplied);
+    QCOMPARE(shmBuffer3->size(), QSize(24, 24));
     for (int i = 0; i < 24; ++i) {
         for (int j = 0; j < 24; ++j) {
             // it's premultiplied in the format
-            QCOMPARE(buffer3->data().pixel(i, j), qRgba(0, 0, 128, 128));
+            QCOMPARE(shmBuffer3->data().pixel(i, j), qRgba(0, 0, 128, 128));
         }
     }
     buffer3->unref();
@@ -492,7 +496,7 @@ void TestWaylandSurface::testAttachBuffer()
     s->attachBuffer(blackBuffer);
     s->damage(QRect(0, 0, 1, 1));
     // TODO: better method
-    s->attachBuffer((wl_buffer*)nullptr);
+    s->attachBuffer((wl_buffer *)nullptr);
     s->damage(QRect(0, 0, 10, 10));
     s->commit(KWayland::Client::Surface::CommitFlag::None);
     QVERIFY(unmappedSpy.wait());
@@ -529,12 +533,12 @@ void TestWaylandSurface::testMultipleSurfaces()
     QVERIFY(serverSurfaceCreated.isValid());
     QScopedPointer<Surface> s1(m_compositor->createSurface());
     QVERIFY(serverSurfaceCreated.wait());
-    SurfaceInterface *serverSurface1 = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface*>();
+    SurfaceInterface *serverSurface1 = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface *>();
     QVERIFY(serverSurface1);
-    //second surface
+    // second surface
     QScopedPointer<Surface> s2(m_compositor->createSurface());
     QVERIFY(serverSurfaceCreated.wait());
-    SurfaceInterface *serverSurface2 = serverSurfaceCreated.last().first().value<KWaylandServer::SurfaceInterface*>();
+    SurfaceInterface *serverSurface2 = serverSurfaceCreated.last().first().value<KWaylandServer::SurfaceInterface *>();
     QVERIFY(serverSurface2);
     QVERIFY(serverSurface1->resource() != serverSurface2->resource());
 
@@ -555,12 +559,12 @@ void TestWaylandSurface::testMultipleSurfaces()
     QVERIFY(damageSpy1.wait());
 
     // now the ServerSurface should have the black image attached as a buffer
-    BufferInterface *buffer1 = serverSurface1->buffer();
+    ClientBuffer *buffer1 = serverSurface1->buffer();
     QVERIFY(buffer1);
-    QImage buffer1Data = buffer1->data();
+    QImage buffer1Data = qobject_cast<ShmClientBuffer *>(buffer1)->data();
     QCOMPARE(buffer1Data, black);
     // accessing the same buffer is OK
-    QImage buffer1Data2 = buffer1->data();
+    QImage buffer1Data2 = qobject_cast<ShmClientBuffer *>(buffer1)->data();
     QCOMPARE(buffer1Data2, buffer1Data);
     buffer1Data = QImage();
     QVERIFY(buffer1Data.isNull());
@@ -575,13 +579,13 @@ void TestWaylandSurface::testMultipleSurfaces()
     QVERIFY(damageSpy2.isValid());
     QVERIFY(damageSpy2.wait());
 
-    BufferInterface *buffer2 = serverSurface2->buffer();
+    ClientBuffer *buffer2 = serverSurface2->buffer();
     QVERIFY(buffer2);
-    QImage buffer2Data = buffer2->data();
+    QImage buffer2Data = qobject_cast<ShmClientBuffer *>(buffer2)->data();
     QCOMPARE(buffer2Data, red);
 
     // while buffer2 is accessed we cannot access buffer1
-    buffer1Data = buffer1->data();
+    buffer1Data = qobject_cast<ShmClientBuffer *>(buffer1)->data();
     QVERIFY(buffer1Data.isNull());
 
     // a deep copy can be kept around
@@ -592,7 +596,7 @@ void TestWaylandSurface::testMultipleSurfaces()
     QCOMPARE(deepCopy, red);
 
     // now that buffer2Data is destroyed we can access buffer1 again
-    buffer1Data = buffer1->data();
+    buffer1Data = qobject_cast<ShmClientBuffer *>(buffer1)->data();
     QVERIFY(!buffer1Data.isNull());
     QCOMPARE(buffer1Data, black);
 }
@@ -605,7 +609,7 @@ void TestWaylandSurface::testOpaque()
     QVERIFY(serverSurfaceCreated.isValid());
     Surface *s = m_compositor->createSurface();
     QVERIFY(serverSurfaceCreated.wait());
-    SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface*>();
+    SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface *>();
     QVERIFY(serverSurface);
     QSignalSpy opaqueRegionChangedSpy(serverSurface, &KWaylandServer::SurfaceInterface::opaqueChanged);
     QVERIFY(opaqueRegionChangedSpy.isValid());
@@ -660,7 +664,7 @@ void TestWaylandSurface::testInput()
     QVERIFY(serverSurfaceCreated.isValid());
     Surface *s = m_compositor->createSurface();
     QVERIFY(serverSurfaceCreated.wait());
-    SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface*>();
+    SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface *>();
     QVERIFY(serverSurface);
     QSignalSpy inputRegionChangedSpy(serverSurface, &KWaylandServer::SurfaceInterface::inputChanged);
     QVERIFY(inputRegionChangedSpy.isValid());
@@ -730,14 +734,14 @@ void TestWaylandSurface::testScale()
     QScopedPointer<Surface> s(m_compositor->createSurface());
     QCOMPARE(s->scale(), 1);
     QVERIFY(serverSurfaceCreated.wait());
-    SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface*>();
+    SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface *>();
     QVERIFY(serverSurface);
     QCOMPARE(serverSurface->bufferScale(), 1);
 
     // let's change the scale factor
     QSignalSpy bufferScaleChangedSpy(serverSurface, &SurfaceInterface::bufferScaleChanged);
 
-    //changing the scale implicitly changes the size
+    // changing the scale implicitly changes the size
     QSignalSpy sizeChangedSpy(serverSurface, &SurfaceInterface::sizeChanged);
 
     QVERIFY(bufferScaleChangedSpy.isValid());
@@ -751,8 +755,8 @@ void TestWaylandSurface::testScale()
     QCOMPARE(bufferScaleChangedSpy.first().first().toInt(), 2);
     QCOMPARE(serverSurface->bufferScale(), 2);
 
-    //even though we've changed the scale, if we don't have a buffer we
-    //don't have a size. If we don't have a size it can't have changed
+    // even though we've changed the scale, if we don't have a buffer we
+    // don't have a size. If we don't have a size it can't have changed
     QCOMPARE(sizeChangedSpy.count(), 0);
     QVERIFY(!serverSurface->size().isValid());
 
@@ -771,32 +775,32 @@ void TestWaylandSurface::testScale()
     QCOMPARE(serverSurface->bufferScale(), 4);
     bufferScaleChangedSpy.clear();
 
-    //attach a buffer of 100x100, our scale is 4, so this should be a size of 25x25
+    // attach a buffer of 100x100, our scale is 4, so this should be a size of 25x25
     QImage red(100, 100, QImage::Format_ARGB32_Premultiplied);
     red.fill(QColor(255, 0, 0, 128));
     QSharedPointer<Buffer> redBuffer = m_shm->createBuffer(red).toStrongRef();
     QVERIFY(redBuffer);
     s->attachBuffer(redBuffer.data());
-    s->damage(QRect(0,0, 25,25));
+    s->damage(QRect(0, 0, 25, 25));
     s->commit(Surface::CommitFlag::None);
     QVERIFY(sizeChangedSpy.wait());
     QCOMPARE(sizeChangedSpy.count(), 1);
-    QCOMPARE(serverSurface->size(), QSize(25,25));
+    QCOMPARE(serverSurface->size(), QSize(25, 25));
     sizeChangedSpy.clear();
     bufferScaleChangedSpy.clear();
 
-    //set the scale to 1, buffer is still 100x100 so size should change to 100x100
+    // set the scale to 1, buffer is still 100x100 so size should change to 100x100
     s->setScale(1);
     s->commit(Surface::CommitFlag::None);
     QVERIFY(sizeChangedSpy.wait());
     QCOMPARE(sizeChangedSpy.count(), 1);
     QCOMPARE(bufferScaleChangedSpy.count(), 1);
     QCOMPARE(serverSurface->bufferScale(), 1);
-    QCOMPARE(serverSurface->size(), QSize(100,100));
+    QCOMPARE(serverSurface->size(), QSize(100, 100));
     sizeChangedSpy.clear();
     bufferScaleChangedSpy.clear();
 
-    //set scale and size in one commit, buffer is 50x50 at scale 2 so size should be 25x25
+    // set scale and size in one commit, buffer is 50x50 at scale 2 so size should be 25x25
     QImage blue(50, 50, QImage::Format_ARGB32_Premultiplied);
     red.fill(QColor(255, 0, 0, 128));
     QSharedPointer<Buffer> blueBuffer = m_shm->createBuffer(blue).toStrongRef();
@@ -808,7 +812,7 @@ void TestWaylandSurface::testScale()
     QCOMPARE(sizeChangedSpy.count(), 1);
     QCOMPARE(bufferScaleChangedSpy.count(), 1);
     QCOMPARE(serverSurface->bufferScale(), 2);
-    QCOMPARE(serverSurface->size(), QSize(25,25));
+    QCOMPARE(serverSurface->size(), QSize(25, 25));
 }
 
 void TestWaylandSurface::testDestroy()
@@ -852,7 +856,7 @@ void TestWaylandSurface::testUnmapOfNotMappedSurface()
     QVERIFY(serverSurfaceCreated.isValid());
     QScopedPointer<Surface> s(m_compositor->createSurface());
     QVERIFY(serverSurfaceCreated.wait());
-    SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface*>();
+    SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface *>();
 
     QSignalSpy unmappedSpy(serverSurface, &SurfaceInterface::unmapped);
     QVERIFY(unmappedSpy.isValid());
@@ -877,7 +881,7 @@ void TestWaylandSurface::testSurfaceAt()
     QVERIFY(serverSurfaceCreated.isValid());
     QScopedPointer<Surface> s(m_compositor->createSurface());
     QVERIFY(serverSurfaceCreated.wait());
-    SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface*>();
+    SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface *>();
 
     // a newly created surface should not be mapped and not provide a surface at a position
     QVERIFY(!serverSurface->isMapped());
@@ -912,7 +916,7 @@ void TestWaylandSurface::testDestroyAttachedBuffer()
     QVERIFY(serverSurfaceCreated.isValid());
     QScopedPointer<Surface> s(m_compositor->createSurface());
     QVERIFY(serverSurfaceCreated.wait());
-    SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface*>();
+    SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface *>();
 
     // let's damage this surface
     QSignalSpy damagedSpy(serverSurface, &SurfaceInterface::damaged);
@@ -931,17 +935,11 @@ void TestWaylandSurface::testDestroyAttachedBuffer()
     m_connection->flush();
 
     // Let's try to destroy it
-    QSignalSpy destroySpy(serverSurface->buffer(), &BufferInterface::aboutToBeDestroyed);
-    QVERIFY(destroySpy.isValid());
     delete m_shm;
     m_shm = nullptr;
-    QVERIFY(destroySpy.wait());
-
-    // TODO: should this emit unmapped?
-    QVERIFY(!serverSurface->buffer());
+    QTRY_VERIFY(serverSurface->buffer()->isDestroyed());
 }
 
-
 void TestWaylandSurface::testDestroyWithPendingCallback()
 {
     // this test tries to verify that destroying a surface with a pending callback works correctly
@@ -954,7 +952,7 @@ void TestWaylandSurface::testDestroyWithPendingCallback()
     QSignalSpy surfaceCreatedSpy(m_compositorInterface, &CompositorInterface::surfaceCreated);
     QVERIFY(surfaceCreatedSpy.isValid());
     QVERIFY(surfaceCreatedSpy.wait());
-    auto serverSurface = surfaceCreatedSpy.first().first().value<SurfaceInterface*>();
+    auto serverSurface = surfaceCreatedSpy.first().first().value<SurfaceInterface *>();
     QVERIFY(serverSurface);
 
     // now render to it
@@ -990,7 +988,7 @@ void TestWaylandSurface::testDisconnect()
     QSignalSpy surfaceCreatedSpy(m_compositorInterface, &CompositorInterface::surfaceCreated);
     QVERIFY(surfaceCreatedSpy.isValid());
     QVERIFY(surfaceCreatedSpy.wait());
-    auto serverSurface = surfaceCreatedSpy.first().first().value<SurfaceInterface*>();
+    auto serverSurface = surfaceCreatedSpy.first().first().value<SurfaceInterface *>();
     QVERIFY(serverSurface);
 
     // destroy client
@@ -1021,7 +1019,7 @@ void TestWaylandSurface::testOutput()
     // This test verifies that the enter/leave are sent correctly to the Client
     using namespace KWayland::Client;
     using namespace KWaylandServer;
-    qRegisterMetaType<KWayland::Client::Output*>();
+    qRegisterMetaType<KWayland::Client::Output *>();
     QScopedPointer<Surface> s(m_compositor->createSurface());
     QVERIFY(!s.isNull());
     QVERIFY(s->isValid());
@@ -1034,9 +1032,9 @@ void TestWaylandSurface::testOutput()
     QSignalSpy surfaceCreatedSpy(m_compositorInterface, &CompositorInterface::surfaceCreated);
     QVERIFY(surfaceCreatedSpy.isValid());
     QVERIFY(surfaceCreatedSpy.wait());
-    auto serverSurface = surfaceCreatedSpy.first().first().value<SurfaceInterface*>();
+    auto serverSurface = surfaceCreatedSpy.first().first().value<SurfaceInterface *>();
     QVERIFY(serverSurface);
-    QCOMPARE(serverSurface->outputs(), QVector<OutputInterface*>());
+    QCOMPARE(serverSurface->outputs(), QVector<OutputInterface *>());
 
     // create another registry to get notified about added outputs
     Registry registry;
@@ -1052,46 +1050,47 @@ void TestWaylandSurface::testOutput()
 
     auto serverOutput = new OutputInterface(m_display, m_display);
     QVERIFY(outputAnnouncedSpy.wait());
-    QScopedPointer<Output> clientOutput(registry.createOutput(outputAnnouncedSpy.first().first().value<quint32>(), outputAnnouncedSpy.first().last().value<quint32>()));
+    QScopedPointer<Output> clientOutput(
+        registry.createOutput(outputAnnouncedSpy.first().first().value<quint32>(), outputAnnouncedSpy.first().last().value<quint32>()));
     QVERIFY(clientOutput->isValid());
     m_connection->flush();
     m_display->dispatchEvents();
 
     // now enter it
-    serverSurface->setOutputs(QVector<OutputInterface*>{serverOutput});
-    QCOMPARE(serverSurface->outputs(), QVector<OutputInterface*>{serverOutput});
+    serverSurface->setOutputs(QVector<OutputInterface *>{serverOutput});
+    QCOMPARE(serverSurface->outputs(), QVector<OutputInterface *>{serverOutput});
     QVERIFY(enteredSpy.wait());
     QCOMPARE(enteredSpy.count(), 1);
-    QCOMPARE(enteredSpy.first().first().value<Output*>(), clientOutput.data());
-    QCOMPARE(s->outputs(), QVector<Output*>{clientOutput.data()});
+    QCOMPARE(enteredSpy.first().first().value<Output *>(), clientOutput.data());
+    QCOMPARE(s->outputs(), QVector<Output *>{clientOutput.data()});
 
     // adding to same should not trigger
-    serverSurface->setOutputs(QVector<OutputInterface*>{serverOutput});
+    serverSurface->setOutputs(QVector<OutputInterface *>{serverOutput});
 
     // leave again
-    serverSurface->setOutputs(QVector<OutputInterface*>());
-    QCOMPARE(serverSurface->outputs(), QVector<OutputInterface*>());
+    serverSurface->setOutputs(QVector<OutputInterface *>());
+    QCOMPARE(serverSurface->outputs(), QVector<OutputInterface *>());
     QVERIFY(leftSpy.wait());
     QCOMPARE(enteredSpy.count(), 1);
     QCOMPARE(leftSpy.count(), 1);
-    QCOMPARE(leftSpy.first().first().value<Output*>(), clientOutput.data());
-    QCOMPARE(s->outputs(), QVector<Output*>());
+    QCOMPARE(leftSpy.first().first().value<Output *>(), clientOutput.data());
+    QCOMPARE(s->outputs(), QVector<Output *>());
 
     // leave again should not trigger
-    serverSurface->setOutputs(QVector<OutputInterface*>());
+    serverSurface->setOutputs(QVector<OutputInterface *>());
 
     // and enter again, just to verify
-    serverSurface->setOutputs(QVector<OutputInterface*>{serverOutput});
-    QCOMPARE(serverSurface->outputs(), QVector<OutputInterface*>{serverOutput});
+    serverSurface->setOutputs(QVector<OutputInterface *>{serverOutput});
+    QCOMPARE(serverSurface->outputs(), QVector<OutputInterface *>{serverOutput});
     QVERIFY(enteredSpy.wait());
     QCOMPARE(enteredSpy.count(), 2);
     QCOMPARE(leftSpy.count(), 1);
 
-    //delete output client is on.
-    //client should get an exit and be left on no outputs (which is allowed)
+    // delete output client is on.
+    // client should get an exit and be left on no outputs (which is allowed)
     serverOutput->deleteLater();
     QVERIFY(leftSpy.wait());
-    QCOMPARE(serverSurface->outputs(), QVector<OutputInterface*>());
+    QCOMPARE(serverSurface->outputs(), QVector<OutputInterface *>());
 }
 
 void TestWaylandSurface::testInhibit()
@@ -1103,7 +1102,7 @@ void TestWaylandSurface::testInhibit()
     QSignalSpy surfaceCreatedSpy(m_compositorInterface, &CompositorInterface::surfaceCreated);
     QVERIFY(surfaceCreatedSpy.isValid());
     QVERIFY(surfaceCreatedSpy.wait());
-    auto serverSurface = surfaceCreatedSpy.first().first().value<SurfaceInterface*>();
+    auto serverSurface = surfaceCreatedSpy.first().first().value<SurfaceInterface *>();
     QVERIFY(serverSurface);
     QCOMPARE(serverSurface->inhibitsIdle(), false);
 
