@@ -13,7 +13,6 @@
 
 namespace KWaylandServer
 {
-
 class ClientConnectionPrivate
 {
 public:
@@ -59,12 +58,10 @@ ClientConnectionPrivate::~ClientConnectionPrivate()
 void ClientConnectionPrivate::destroyListenerCallback(wl_listener *listener, void *data)
 {
     Q_UNUSED(listener)
-    wl_client *client = reinterpret_cast<wl_client*>(data);
-    auto it = std::find_if(s_allClients.constBegin(), s_allClients.constEnd(),
-        [client](ClientConnectionPrivate *c) {
-            return c->client == client;
-        }
-    );
+    wl_client *client = reinterpret_cast<wl_client *>(data);
+    auto it = std::find_if(s_allClients.constBegin(), s_allClients.constEnd(), [client](ClientConnectionPrivate *c) {
+        return c->client == client;
+    });
     Q_ASSERT(it != s_allClients.constEnd());
     auto p = (*it);
     auto q = p->q;
@@ -99,15 +96,7 @@ void ClientConnection::destroy()
     wl_client_destroy(d->client);
 }
 
-wl_resource *ClientConnection::createResource(const wl_interface *interface, quint32 version, quint32 id)
-{
-    if (!d->client) {
-        return nullptr;
-    }
-    return wl_resource_create(d->client, interface, version, id);
-}
-
-wl_resource *ClientConnection::getResource(quint32 id)
+wl_resource *ClientConnection::getResource(quint32 id) const
 {
     if (!d->client) {
         return nullptr;
@@ -120,12 +109,12 @@ wl_client *ClientConnection::client() const
     return d->client;
 }
 
-ClientConnection::operator wl_client*()
+ClientConnection::operator wl_client *()
 {
     return d->client;
 }
 
-ClientConnection::operator wl_client*() const
+ClientConnection::operator wl_client *() const
 {
     return d->client;
 }
