@@ -13,7 +13,6 @@ struct wl_resource;
 
 namespace KWaylandServer
 {
-
 class AbstractDataSource;
 class DataControlDeviceManagerV1Interface;
 class DataControlDeviceV1InterfacePrivate;
@@ -36,14 +35,20 @@ public:
 
     SeatInterface *seat() const;
     DataControlSourceV1Interface *selection() const;
+    DataControlSourceV1Interface *primarySelection() const;
 
     void sendSelection(AbstractDataSource *other);
     void sendClearSelection();
 
+    void sendPrimarySelection(AbstractDataSource *other);
+    void sendClearPrimarySelection();
+
 Q_SIGNALS:
     void selectionChanged(KWaylandServer::DataControlSourceV1Interface *dataSource);
     void selectionCleared();
 
+    void primarySelectionChanged(KWaylandServer::DataControlSourceV1Interface *dataSource);
+
 private:
     friend class DataControlDeviceManagerV1InterfacePrivate;
     explicit DataControlDeviceV1Interface(SeatInterface *seat, wl_resource *resource);
@@ -53,4 +58,4 @@ private:
 
 }
 
-Q_DECLARE_METATYPE(KWaylandServer::DataControlDeviceV1Interface*)
+Q_DECLARE_METATYPE(KWaylandServer::DataControlDeviceV1Interface *)
