@@ -3,8 +3,7 @@
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
-#ifndef WAYLAND_SERVER_DATA_CONTROL_DEVICE_MANAGER_INTERFACE_H
-#define WAYLAND_SERVER_DATA_CONTROL_DEVICE_MANAGER_INTERFACE_H
+#pragma once
 
 #include <QObject>
 
@@ -12,7 +11,6 @@
 
 namespace KWaylandServer
 {
-
 class Display;
 class DataControlSourceV1Interface;
 class DataControlDeviceManagerV1InterfacePrivate;
@@ -41,5 +39,3 @@ private:
 };
 
 }
-
-#endif
