@@ -9,6 +9,7 @@
 
 #include <wayland-server-core.h>
 
+#include <QHash>
 #include <QList>
 #include <QSocketNotifier>
 #include <QString>
@@ -16,14 +17,18 @@
 
 #include <EGL/egl.h>
 
+struct wl_resource;
+
 namespace KWaylandServer
 {
-
+class ClientBufferIntegration;
+class ClientBuffer;
 class ClientConnection;
 class Display;
 class OutputInterface;
-class OutputDeviceInterface;
+class OutputDeviceV2Interface;
 class SeatInterface;
+struct ClientBufferDestroyListener;
 
 class DisplayPrivate
 {
@@ -33,17 +38,23 @@ public:
 
     void registerSocketName(const QString &socketName);
 
+    void registerClientBuffer(ClientBuffer *clientBuffer);
+    void unregisterClientBuffer(ClientBuffer *clientBuffer);
+
     Display *q;
     QSocketNotifier *socketNotifier = nullptr;
     wl_display *display = nullptr;
     wl_event_loop *loop = nullptr;
     bool running = false;
     QList<OutputInterface *> outputs;
-    QList<OutputDeviceInterface *> outputdevices;
+    QList<OutputDeviceV2Interface *> outputdevicesV2;
     QVector<SeatInterface *> seats;
     QVector<ClientConnection *> clients;
     QStringList socketNames;
     EGLDisplay eglDisplay = EGL_NO_DISPLAY;
+    QHash<::wl_resource *, ClientBuffer *> resourceToBuffer;
+    QHash<ClientBuffer *, ClientBufferDestroyListener *> bufferToListener;
+    QList<ClientBufferIntegration *> bufferIntegrations;
 };
 
 } // namespace KWaylandServer
