@@ -6,24 +6,24 @@
 #include "plasmawindowmanagement_interface.h"
 #include "display.h"
 #include "logging.h"
-#include "surface_interface.h"
 #include "plasmavirtualdesktop_interface.h"
+#include "surface_interface.h"
 
-#include <QtConcurrentRun>
 #include <QFile>
+#include <QHash>
 #include <QIcon>
 #include <QList>
-#include <QVector>
 #include <QRect>
-#include <QHash>
 #include <QUuid>
+#include <QVector>
+#include <QtConcurrentRun>
 
 #include <qwayland-server-plasma-window-management.h>
 
 namespace KWaylandServer
 {
-
 static const quint32 s_version = 14;
+static const quint32 s_activationVersion = 1;
 
 class PlasmaWindowManagementInterfacePrivate : public QtWaylandServer::org_kde_plasma_window_management
 {
@@ -37,7 +37,7 @@ public:
     void sendStackingOrderUuidsChanged(wl_resource *resource);
 
     PlasmaWindowManagementInterface::ShowingDesktopState state = PlasmaWindowManagementInterface::ShowingDesktopState::Disabled;
-    QList<PlasmaWindowInterface*> windows;
+    QList<PlasmaWindowInterface *> windows;
     QPointer<PlasmaVirtualDesktopManagementInterface> plasmaVirtualDesktopManagementInterface = nullptr;
     quint32 windowIdCounter = 0;
     QVector<quint32> stackingOrder;
@@ -71,7 +71,7 @@ public:
     wl_resource *resourceForParent(PlasmaWindowInterface *parent, Resource *child) const;
 
     quint32 windowId = 0;
-    QHash<SurfaceInterface*, QRect> minimizedGeometries;
+    QHash<SurfaceInterface *, QRect> minimizedGeometries;
     PlasmaWindowManagementInterface *wm;
 
     bool unmapped = false;
@@ -108,6 +108,7 @@ protected:
     void org_kde_plasma_window_request_leave_virtual_desktop(Resource *resource, const QString &id) override;
     void org_kde_plasma_window_request_enter_activity(Resource *resource, const QString &id) override;
     void org_kde_plasma_window_request_leave_activity(Resource *resource, const QString &id) override;
+    void org_kde_plasma_window_send_to_output(Resource *resource, struct wl_resource *output) override;
 };
 
 PlasmaWindowManagementInterfacePrivate::PlasmaWindowManagementInterfacePrivate(PlasmaWindowManagementInterface *_q, Display *display)
@@ -155,7 +156,7 @@ void PlasmaWindowManagementInterfacePrivate::sendStackingOrderChanged(wl_resourc
         return;
     }
 
-    send_stacking_order_changed(r, QByteArray::fromRawData(reinterpret_cast<const char*>(stackingOrder.constData()), sizeof(uint32_t) * stackingOrder.size()));
+    send_stacking_order_changed(r, QByteArray::fromRawData(reinterpret_cast<const char *>(stackingOrder.constData()), sizeof(uint32_t) * stackingOrder.size()));
 }
 
 void PlasmaWindowManagementInterfacePrivate::sendStackingOrderUuidsChanged()
@@ -226,13 +227,13 @@ void PlasmaWindowManagementInterfacePrivate::org_kde_plasma_window_management_ge
     window.d->add(resource->client(), id, resource->version());
 }
 
-void PlasmaWindowManagementInterfacePrivate::org_kde_plasma_window_management_get_window_by_uuid(Resource *resource, uint32_t id, const QString &internal_window_uuid)
+void PlasmaWindowManagementInterfacePrivate::org_kde_plasma_window_management_get_window_by_uuid(Resource *resource,
+                                                                                                 uint32_t id,
+                                                                                                 const QString &internal_window_uuid)
 {
-    auto it = std::find_if(windows.constBegin(), windows.constEnd(),
-        [internal_window_uuid] (PlasmaWindowInterface *window) {
-            return window->d->uuid == internal_window_uuid;
-        }
-    );
+    auto it = std::find_if(windows.constBegin(), windows.constEnd(), [internal_window_uuid](PlasmaWindowInterface *window) {
+        return window->d->uuid == internal_window_uuid;
+    });
     if (it == windows.constEnd()) {
         qCWarning(KWAYLAND_SERVER) << "Could not find window with uuid" << internal_window_uuid;
         // create a temp window just for the resource, bind then immediately delete it, sending an unmap event
@@ -265,7 +266,7 @@ PlasmaWindowInterface *PlasmaWindowManagementInterface::createWindow(QObject *pa
     PlasmaWindowInterface *window = new PlasmaWindowInterface(this, parent);
 
     window->d->uuid = uuid.toString();
-    window->d->windowId = ++d->windowIdCounter; //NOTE the window id is deprecated
+    window->d->windowId = ++d->windowIdCounter; // NOTE the window id is deprecated
 
     const auto clientResources = d->resourceMap();
     for (auto resource : clientResources) {
@@ -276,15 +277,13 @@ PlasmaWindowInterface *PlasmaWindowManagementInterface::createWindow(QObject *pa
         }
     }
     d->windows << window;
-    connect(window, &QObject::destroyed, this,
-        [this, window] {
-            d->windows.removeAll(window);
-        }
-    );
+    connect(window, &QObject::destroyed, this, [this, window] {
+        d->windows.removeAll(window);
+    });
     return window;
 }
 
-QList<PlasmaWindowInterface*> PlasmaWindowManagementInterface::windows() const
+QList<PlasmaWindowInterface *> PlasmaWindowManagementInterface::windows() const
 {
     return d->windows;
 }
@@ -340,7 +339,6 @@ void PlasmaWindowInterfacePrivate::org_kde_plasma_window_destroy(Resource *resou
 
 void PlasmaWindowInterfacePrivate::org_kde_plasma_window_bind_resource(Resource *resource)
 {
-
     send_virtual_desktop_changed(resource->handle, m_virtualDesktop);
 
     for (const auto &desk : plasmaVirtualDesktops) {
@@ -393,7 +391,7 @@ void PlasmaWindowInterfacePrivate::setAppId(const QString &appId)
     const auto clientResources = resourceMap();
 
     for (auto resource : clientResources) {
-        send_app_id_changed(resource->handle,m_appId);
+        send_app_id_changed(resource->handle, m_appId);
     }
 }
 
@@ -406,7 +404,7 @@ void PlasmaWindowInterfacePrivate::setPid(quint32 pid)
     const auto clientResources = resourceMap();
 
     for (auto resource : clientResources) {
-        send_pid_changed(resource->handle,pid);
+        send_pid_changed(resource->handle, pid);
     }
 }
 
@@ -434,21 +432,20 @@ void PlasmaWindowInterfacePrivate::setIcon(const QIcon &icon)
             send_icon_changed(resource->handle);
         }
     }
-
 }
 
 void PlasmaWindowInterfacePrivate::org_kde_plasma_window_get_icon(Resource *resource, int32_t fd)
 {
     Q_UNUSED(resource)
     QtConcurrent::run(
-        [fd] (const QIcon &icon) {
+        [fd](const QIcon &icon) {
             QFile file;
             file.open(fd, QIODevice::WriteOnly, QFileDevice::AutoCloseHandle);
             QDataStream ds(&file);
             ds << icon;
             file.close();
-        }, m_icon
-    );
+        },
+        m_icon);
 }
 
 void PlasmaWindowInterfacePrivate::org_kde_plasma_window_request_enter_virtual_desktop(Resource *resource, const QString &id)
@@ -481,6 +478,12 @@ void PlasmaWindowInterfacePrivate::org_kde_plasma_window_request_leave_activity(
     Q_EMIT q->leavePlasmaActivityRequested(id);
 }
 
+void PlasmaWindowInterfacePrivate::org_kde_plasma_window_send_to_output(Resource *resource, struct wl_resource *output)
+{
+    Q_UNUSED(resource)
+    Q_EMIT q->sendToOutput(KWaylandServer::OutputInterface::get(output));
+}
+
 void PlasmaWindowInterfacePrivate::setTitle(const QString &title)
 {
     if (m_title == title) {
@@ -564,16 +567,14 @@ void PlasmaWindowInterfacePrivate::setParentWindow(PlasmaWindowInterface *window
     parentWindowDestroyConnection = QMetaObject::Connection();
     parentWindow = window;
     if (parentWindow) {
-        parentWindowDestroyConnection = QObject::connect(window, &QObject::destroyed, q,
-            [this] {
-                parentWindow = nullptr;
-                parentWindowDestroyConnection = QMetaObject::Connection();
-                const auto clientResources = resourceMap();
-                for (auto resource : clientResources) {
-                    send_parent_window(resource->handle, nullptr);
-                }
+        parentWindowDestroyConnection = QObject::connect(window, &QObject::destroyed, q, [this] {
+            parentWindow = nullptr;
+            parentWindowDestroyConnection = QMetaObject::Connection();
+            const auto clientResources = resourceMap();
+            for (auto resource : clientResources) {
+                send_parent_window(resource->handle, nullptr);
             }
-        );
+        });
     }
     const auto clientResources = resourceMap();
     for (auto resource : clientResources) {
@@ -699,7 +700,12 @@ void PlasmaWindowInterfacePrivate::org_kde_plasma_window_set_state(Resource *res
     }
 }
 
-void PlasmaWindowInterfacePrivate::org_kde_plasma_window_set_minimized_geometry(Resource *resource, wl_resource *panel, uint32_t x, uint32_t y, uint32_t width, uint32_t height)
+void PlasmaWindowInterfacePrivate::org_kde_plasma_window_set_minimized_geometry(Resource *resource,
+                                                                                wl_resource *panel,
+                                                                                uint32_t x,
+                                                                                uint32_t y,
+                                                                                uint32_t width,
+                                                                                uint32_t height)
 {
     Q_UNUSED(resource)
     SurfaceInterface *panelSurface = SurfaceInterface::get(panel);
@@ -714,7 +720,7 @@ void PlasmaWindowInterfacePrivate::org_kde_plasma_window_set_minimized_geometry(
 
     minimizedGeometries[panelSurface] = QRect(x, y, width, height);
     Q_EMIT q->minimizedGeometriesChanged();
-    QObject::connect(panelSurface, &QObject::destroyed, q, [this, panelSurface] () {
+    QObject::connect(panelSurface, &QObject::destroyed, q, [this, panelSurface]() {
         if (minimizedGeometries.remove(panelSurface)) {
             Q_EMIT q->minimizedGeometriesChanged();
         }
@@ -769,7 +775,7 @@ void PlasmaWindowInterface::unmap()
     d->unmap();
 }
 
-QHash<SurfaceInterface*, QRect>  PlasmaWindowInterface::minimizedGeometries() const
+QHash<SurfaceInterface *, QRect> PlasmaWindowInterface::minimizedGeometries() const
 {
     return d->minimizedGeometries;
 }
@@ -806,19 +812,19 @@ void PlasmaWindowInterface::setMinimized(bool set)
 
 void PlasmaWindowInterface::setOnAllDesktops(bool set)
 {
-    //the deprecated vd management
+    // the deprecated vd management
     d->setState(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_ON_ALL_DESKTOPS, set);
 
     if (!d->wm->plasmaVirtualDesktopManagementInterface()) {
         return;
     }
     const auto clientResources = d->resourceMap();
-    //the current vd management
+    // the current vd management
     if (set) {
         if (d->plasmaVirtualDesktops.isEmpty()) {
             return;
         }
-        //leaving everything means on all desktops
+        // leaving everything means on all desktops
         for (auto desk : plasmaVirtualDesktops()) {
             for (auto resource : clientResources) {
                 d->send_virtual_desktop_left(resource->handle, desk);
@@ -829,7 +835,7 @@ void PlasmaWindowInterface::setOnAllDesktops(bool set)
         if (!d->plasmaVirtualDesktops.isEmpty()) {
             return;
         }
-        //enters the desktops which are active (usually only one  but not a given)
+        // enters the desktops which are active (usually only one  but not a given)
         for (auto desk : d->wm->plasmaVirtualDesktopManagementInterface()->desktops()) {
             if (desk->isActive() && !d->plasmaVirtualDesktops.contains(desk->id())) {
                 d->plasmaVirtualDesktops << desk->id();
@@ -888,7 +894,7 @@ void PlasmaWindowInterface::setIcon(const QIcon &icon)
 
 void PlasmaWindowInterface::addPlasmaVirtualDesktop(const QString &id)
 {
-    //don't add a desktop we're not sure it exists
+    // don't add a desktop we're not sure it exists
     if (!d->wm->plasmaVirtualDesktopManagementInterface() || d->plasmaVirtualDesktops.contains(id)) {
         return;
     }
@@ -901,10 +907,10 @@ void PlasmaWindowInterface::addPlasmaVirtualDesktop(const QString &id)
 
     d->plasmaVirtualDesktops << id;
 
-    //if the desktop dies, remove it from or list
-    connect(desktop, &QObject::destroyed,
-            this, [this, id](){removePlasmaVirtualDesktop(id);});
-
+    // if the desktop dies, remove it from or list
+    connect(desktop, &QObject::destroyed, this, [this, id]() {
+        removePlasmaVirtualDesktop(id);
+    });
 
     const auto clientResources = d->resourceMap();
     for (auto resource : clientResources) {
@@ -924,7 +930,7 @@ void PlasmaWindowInterface::removePlasmaVirtualDesktop(const QString &id)
         d->send_virtual_desktop_left(resource->handle, id);
     }
 
-    //we went on all desktops
+    // we went on all desktops
     if (d->plasmaVirtualDesktops.isEmpty()) {
         setOnAllDesktops(true);
     }
@@ -1020,4 +1026,78 @@ QString PlasmaWindowInterface::uuid() const
     return d->uuid;
 }
 
+class PlasmaWindowActivationFeedbackInterfacePrivate : public QtWaylandServer::org_kde_plasma_activation_feedback
+{
+public:
+    PlasmaWindowActivationFeedbackInterfacePrivate(Display *display);
+
+protected:
+    void org_kde_plasma_activation_feedback_destroy(Resource *resource) override;
+};
+
+class PlasmaWindowActivationInterfacePrivate : public QtWaylandServer::org_kde_plasma_activation
+{
+public:
+    PlasmaWindowActivationInterfacePrivate(PlasmaWindowActivationInterface *q)
+        : QtWaylandServer::org_kde_plasma_activation()
+        , q(q)
+    {
+    }
+
+    PlasmaWindowActivationInterface *const q;
+};
+
+PlasmaWindowActivationFeedbackInterfacePrivate::PlasmaWindowActivationFeedbackInterfacePrivate(Display *display)
+    : QtWaylandServer::org_kde_plasma_activation_feedback(*display, s_activationVersion)
+{
+}
+
+void PlasmaWindowActivationFeedbackInterfacePrivate::org_kde_plasma_activation_feedback_destroy(Resource *resource)
+{
+    wl_resource_destroy(resource->handle);
+}
+
+PlasmaWindowActivationFeedbackInterface::PlasmaWindowActivationFeedbackInterface(Display *display, QObject *parent)
+    : QObject(parent)
+    , d(new PlasmaWindowActivationFeedbackInterfacePrivate(display))
+{
+}
+
+PlasmaWindowActivationFeedbackInterface::~PlasmaWindowActivationFeedbackInterface()
+{
+}
+
+PlasmaWindowActivationInterface *PlasmaWindowActivationFeedbackInterface::createActivation(const QString &appid)
+{
+    auto activation = new PlasmaWindowActivationInterface;
+    const auto resources = d->resourceMap();
+    for (auto resource : resources) {
+        auto activationResource = activation->d->add(resource->client(), resource->version());
+        d->send_activation(resource->handle, activationResource->handle);
+    }
+    activation->sendAppId(appid);
+    return activation;
+}
+
+PlasmaWindowActivationInterface::PlasmaWindowActivationInterface()
+    : d(new PlasmaWindowActivationInterfacePrivate(this))
+{
+}
+
+PlasmaWindowActivationInterface::~PlasmaWindowActivationInterface()
+{
+    const auto clientResources = d->resourceMap();
+    for (auto resource : clientResources) {
+        d->send_finished(resource->handle);
+    }
+}
+
+void PlasmaWindowActivationInterface::sendAppId(const QString &appid)
+{
+    const auto clientResources = d->resourceMap();
+    for (auto resource : clientResources) {
+        d->send_app_id(resource->handle, appid);
+    }
+}
+
 }
