@@ -13,17 +13,50 @@ class QSize;
 
 namespace KWaylandServer
 {
-
 class Display;
+class OutputInterface;
+class PlasmaWindowActivationFeedbackInterfacePrivate;
 class PlasmaWindowInterface;
-class SurfaceInterface;
 class PlasmaVirtualDesktopManagementInterface;
+class PlasmaWindowActivationInterfacePrivate;
 class PlasmaWindowManagementInterfacePrivate;
 class PlasmaWindowInterfacePrivate;
+class SurfaceInterface;
+
+class KWAYLANDSERVER_EXPORT PlasmaWindowActivationInterface
+{
+public:
+    ~PlasmaWindowActivationInterface();
+
+    void sendAppId(const QString &id);
+
+private:
+    friend class PlasmaWindowActivationFeedbackInterface;
+    explicit PlasmaWindowActivationInterface();
+
+    QScopedPointer<PlasmaWindowActivationInterfacePrivate> d;
+};
+
+class KWAYLANDSERVER_EXPORT PlasmaWindowActivationFeedbackInterface : public QObject
+{
+    Q_OBJECT
+
+public:
+    explicit PlasmaWindowActivationFeedbackInterface(Display *display, QObject *parent = nullptr);
+    ~PlasmaWindowActivationFeedbackInterface() override;
+
+    /**
+     * Notify about a new application with @p app_id being started
+     *
+     * @returns an instance of @class PlasmaWindowActivationInterface to
+     * be destroyed as the activation process ends.
+     */
+    PlasmaWindowActivationInterface *createActivation(const QString &app_id);
+
+private:
+    QScopedPointer<PlasmaWindowActivationFeedbackInterfacePrivate> d;
+};
 
-/**
- * @todo Add documentation
- */
 class KWAYLANDSERVER_EXPORT PlasmaWindowManagementInterface : public QObject
 {
     Q_OBJECT
@@ -38,7 +71,7 @@ public:
     void setShowingDesktopState(ShowingDesktopState state);
 
     PlasmaWindowInterface *createWindow(QObject *parent, const QUuid &uuid);
-    QList<PlasmaWindowInterface*> windows() const;
+    QList<PlasmaWindowInterface *> windows() const;
 
     /**
      * Associate a PlasmaVirtualDesktopManagementInterface to this window management.
@@ -52,7 +85,6 @@ public:
      */
     PlasmaVirtualDesktopManagementInterface *plasmaVirtualDesktopManagementInterface() const;
 
-
     /**
      * Associate stacking order to this window management
      */
@@ -83,7 +115,10 @@ public:
     /**
      * @deprecated Since 5.52, use addPlasmaVirtualDesktop and removePlasmaVirtualDesktop
      */
-    KWAYLANDSERVER_DEPRECATED_VERSION(5, 52, "Use PlasmaWindowManagementInterface::addPlasmaVirtualDesktop(const QString&) and PlasmaWindowManagementInterface::removePlasmaVirtualDesktop(const QString&)")
+    KWAYLANDSERVER_DEPRECATED_VERSION(5,
+                                      52,
+                                      "Use PlasmaWindowManagementInterface::addPlasmaVirtualDesktop(const QString&) and "
+                                      "PlasmaWindowManagementInterface::removePlasmaVirtualDesktop(const QString&)")
     void setVirtualDesktop(quint32 desktop);
 #endif
     void setActive(bool set);
@@ -128,7 +163,7 @@ public:
      * @returns Geometries of the taskbar entries, indicized by the
      *          surface of the panels
      */
-    QHash<SurfaceInterface*, QRect> minimizedGeometries() const;
+    QHash<SurfaceInterface *, QRect> minimizedGeometries() const;
 
     /**
      * Sets this PlasmaWindowInterface as a transient window to @p parentWindow.
@@ -215,7 +250,10 @@ Q_SIGNALS:
     /**
      * @deprecated Since 5.52, use enterPlasmaVirtualDesktopRequested and leavePlasmaVirtualDesktopRequested instead
      */
-    KWAYLANDSERVER_DEPRECATED_VERSION(5, 52, "Use PlasmaWindowManagementInterface::enterPlasmaVirtualDesktopRequested(const QString&) and PlasmaWindowManagementInterface::leavePlasmaVirtualDesktopRequested(const QString&)")
+    KWAYLANDSERVER_DEPRECATED_VERSION(5,
+                                      52,
+                                      "Use PlasmaWindowManagementInterface::enterPlasmaVirtualDesktopRequested(const QString&) and "
+                                      "PlasmaWindowManagementInterface::leavePlasmaVirtualDesktopRequested(const QString&)")
     void virtualDesktopRequested(quint32 desktop);
 #endif
     void activeRequested(bool set);
@@ -272,6 +310,11 @@ Q_SIGNALS:
      */
     void leavePlasmaActivityRequested(const QString &activity);
 
+    /**
+     * Requests sending the window to @p output
+     */
+    void sendToOutput(KWaylandServer::OutputInterface *output);
+
 private:
     friend class PlasmaWindowManagementInterface;
     friend class PlasmaWindowInterfacePrivate;
