@@ -5,26 +5,26 @@
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
-#include "abstract_data_source.h"
-#include "display_p.h"
 #include "seat_interface.h"
-#include "seat_interface_p.h"
-#include "display.h"
+#include "abstract_data_source.h"
+#include "datacontroldevice_v1_interface.h"
+#include "datacontrolsource_v1_interface.h"
 #include "datadevice_interface.h"
 #include "datadevice_interface_p.h"
 #include "datasource_interface.h"
-#include "datacontroldevice_v1_interface.h"
-#include "datacontrolsource_v1_interface.h"
+#include "display.h"
+#include "display_p.h"
 #include "keyboard_interface.h"
 #include "keyboard_interface_p.h"
 #include "logging.h"
-#include "pointerconstraints_v1_interface.h"
-#include "pointergestures_v1_interface_p.h"
 #include "pointer_interface.h"
 #include "pointer_interface_p.h"
+#include "pointerconstraints_v1_interface.h"
+#include "pointergestures_v1_interface_p.h"
 #include "primaryselectiondevice_v1_interface.h"
 #include "primaryselectionsource_v1_interface.h"
 #include "relativepointer_v1_interface_p.h"
+#include "seat_interface_p.h"
 #include "surface_interface.h"
 #include "textinput_v2_interface_p.h"
 #include "textinput_v3_interface_p.h"
@@ -40,7 +40,6 @@
 
 namespace KWaylandServer
 {
-
 static const int s_version = 7;
 
 SeatInterfacePrivate *SeatInterfacePrivate::get(SeatInterface *seat)
@@ -166,58 +165,18 @@ void SeatInterfacePrivate::registerDataDevice(DataDeviceInterface *dataDevice)
         globalKeyboard.focus.selections.removeOne(dataDevice);
     };
     QObject::connect(dataDevice, &QObject::destroyed, q, dataDeviceCleanup);
-    QObject::connect(dataDevice, &DataDeviceInterface::selectionChanged, q,
-        [this, dataDevice] {
-            updateSelection(dataDevice);
-        }
-    );
-    QObject::connect(dataDevice, &DataDeviceInterface::selectionCleared, q,
-        [this, dataDevice] {
-            updateSelection(dataDevice);
-        }
-    );
-    QObject::connect(dataDevice, &DataDeviceInterface::dragStarted, q,
-        [this, dataDevice] {
-            const auto dragSerial = dataDevice->dragImplicitGrabSerial();
-            if (q->hasImplicitPointerGrab(dragSerial)) {
-                drag.mode = Drag::Mode::Pointer;
-                drag.transformation = globalPointer.focus.transformation;
-            } else if (q->hasImplicitTouchGrab(dragSerial)) {
-                drag.mode = Drag::Mode::Touch;
-                // TODO: touch transformation
-            } else {
-                // no implicit grab, abort drag
-                return;
-            }
-            auto *originSurface = dataDevice->origin();
-            const bool proxied = originSurface->dataProxy();
-            if (!proxied) {
-                // origin surface
-                drag.target = dataDevice;
-                drag.surface = originSurface;
-                // TODO: transformation needs to be either pointer or touch
-                drag.transformation = globalPointer.focus.transformation;
-            }
-            drag.source = dataDevice;
-            drag.destroyConnection = QObject::connect(dataDevice, &DataDeviceInterface::aboutToBeDestroyed, q,
-                [this] {
-                    cancelDrag(display->nextSerial());
-                }
-            );
-            if (dataDevice->dragSource()) {
-                drag.dragSourceDestroyConnection = QObject::connect(dataDevice->dragSource(), &AbstractDataSource::aboutToBeDestroyed, q,
-                    [this] {
-                        cancelDrag(display->nextSerial());
-                    }
-                );
-            } else {
-                drag.dragSourceDestroyConnection = QMetaObject::Connection();
-            }
-            dataDevice->updateDragTarget(proxied ? nullptr : originSurface, dataDevice->dragImplicitGrabSerial());
-            Q_EMIT q->dragStarted();
-            Q_EMIT q->dragSurfaceChanged();
-        }
-    );
+    QObject::connect(dataDevice, &DataDeviceInterface::selectionChanged, q, [this, dataDevice] {
+        updateSelection(dataDevice);
+    });
+    QObject::connect(dataDevice, &DataDeviceInterface::selectionCleared, q, [this, dataDevice] {
+        updateSelection(dataDevice);
+    });
+    QObject::connect(dataDevice,
+                     &DataDeviceInterface::dragStarted,
+                     q,
+                     [this](AbstractDataSource *source, SurfaceInterface *origin, quint32 serial, DragAndDropIcon *dragIcon) {
+                         q->startDrag(source, origin, serial, dragIcon);
+                     });
     // is the new DataDevice for the current keyoard focus?
     if (globalKeyboard.focus.surface) {
         // same client?
@@ -230,6 +189,15 @@ void SeatInterfacePrivate::registerDataDevice(DataDeviceInterface *dataDevice)
     }
 }
 
+KWaylandServer::AbstractDropHandler *SeatInterface::dropHandlerForSurface(SurfaceInterface *surface) const
+{
+    auto list = d->dataDevicesForSurface(surface);
+    if (list.isEmpty()) {
+        return nullptr;
+    };
+    return list.first();
+}
+
 void SeatInterfacePrivate::registerDataControlDevice(DataControlDeviceV1Interface *dataDevice)
 {
     Q_ASSERT(dataDevice->seat() == q);
@@ -239,29 +207,40 @@ void SeatInterfacePrivate::registerDataControlDevice(DataControlDeviceV1Interfac
     };
     QObject::connect(dataDevice, &QObject::destroyed, q, dataDeviceCleanup);
 
-    QObject::connect(dataDevice, &DataControlDeviceV1Interface::selectionChanged, q,
-                     [this, dataDevice] {
+    QObject::connect(dataDevice, &DataControlDeviceV1Interface::selectionChanged, q, [this, dataDevice] {
         // Special klipper workaround to avoid a race
         // If the mimetype x-kde-onlyReplaceEmpty is set, and we've had another update in the meantime, do nothing
         // See https://github.com/swaywm/wlr-protocols/issues/92
-        if  (dataDevice->selection() && dataDevice->selection()->mimeTypes().contains(QLatin1String("application/x-kde-onlyReplaceEmpty")) &&
-             currentSelection) {
+        if (dataDevice->selection() && dataDevice->selection()->mimeTypes().contains(QLatin1String("application/x-kde-onlyReplaceEmpty")) && currentSelection) {
             dataDevice->selection()->cancel();
             return;
         }
         q->setSelection(dataDevice->selection());
-    }
-    );
+    });
 
-    QObject::connect(dataDevice, &DataControlDeviceV1Interface::selectionCleared, q,
-        [this, dataDevice] {
-            Q_UNUSED(dataDevice);
-            q->setSelection(nullptr);
+    QObject::connect(dataDevice, &DataControlDeviceV1Interface::selectionCleared, q, [this, dataDevice] {
+        Q_UNUSED(dataDevice);
+        q->setSelection(nullptr);
+    });
+
+    QObject::connect(dataDevice, &DataControlDeviceV1Interface::primarySelectionChanged, q, [this, dataDevice] {
+        // Special klipper workaround to avoid a race
+        // If the mimetype x-kde-onlyReplaceEmpty is set, and we've had another update in the meantime, do nothing
+        // See https://github.com/swaywm/wlr-protocols/issues/92
+        if (dataDevice->primarySelection() && dataDevice->primarySelection()->mimeTypes().contains(QLatin1String("application/x-kde-onlyReplaceEmpty"))
+            && currentPrimarySelection) {
+            dataDevice->primarySelection()->cancel();
+            return;
         }
-    );
+        q->setPrimarySelection(dataDevice->primarySelection());
+    });
+
     if (currentSelection) {
         dataDevice->sendSelection(currentSelection);
     }
+    if (currentPrimarySelection) {
+        dataDevice->sendPrimarySelection(currentPrimarySelection);
+    }
 }
 
 void SeatInterfacePrivate::registerPrimarySelectionDevice(PrimarySelectionDeviceV1Interface *primarySelectionDevice)
@@ -274,16 +253,12 @@ void SeatInterfacePrivate::registerPrimarySelectionDevice(PrimarySelectionDevice
         globalKeyboard.focus.primarySelections.removeOne(primarySelectionDevice);
     };
     QObject::connect(primarySelectionDevice, &QObject::destroyed, q, dataDeviceCleanup);
-    QObject::connect(primarySelectionDevice, &PrimarySelectionDeviceV1Interface::selectionChanged, q,
-        [this, primarySelectionDevice] {
-            updatePrimarySelection(primarySelectionDevice);
-        }
-    );
-    QObject::connect(primarySelectionDevice, &PrimarySelectionDeviceV1Interface::selectionCleared, q,
-        [this, primarySelectionDevice] {
-            updatePrimarySelection(primarySelectionDevice);
-        }
-    );
+    QObject::connect(primarySelectionDevice, &PrimarySelectionDeviceV1Interface::selectionChanged, q, [this, primarySelectionDevice] {
+        updatePrimarySelection(primarySelectionDevice);
+    });
+    QObject::connect(primarySelectionDevice, &PrimarySelectionDeviceV1Interface::selectionCleared, q, [this, primarySelectionDevice] {
+        updatePrimarySelection(primarySelectionDevice);
+    });
     // is the new DataDevice for the current keyoard focus?
     if (globalKeyboard.focus.surface) {
         // same client?
@@ -307,12 +282,10 @@ void SeatInterfacePrivate::cancelDrag(quint32 serial)
 
 void SeatInterfacePrivate::endDrag(quint32 serial)
 {
-    QObject::disconnect(drag.destroyConnection);
     QObject::disconnect(drag.dragSourceDestroyConnection);
 
-    DataDeviceInterface *dragTargetDevice = drag.target;
-    DataDeviceInterface *dragSourceDevice = drag.source;
-    DataSourceInterface *dragSource = dragSourceDevice ? dragSourceDevice->dragSource() : nullptr;
+    AbstractDropHandler *dragTargetDevice = drag.target.data();
+    AbstractDataSource *dragSource = drag.source;
     if (dragSource) {
         // TODO: Also check the current drag-and-drop action.
         if (dragTargetDevice && dragSource->isAccepted()) {
@@ -320,20 +293,13 @@ void SeatInterfacePrivate::endDrag(quint32 serial)
             dragTargetDevice->drop();
             dragSource->dropPerformed();
         } else {
-            if (wl_resource_get_version(dragSource->resource()) >=
-                    WL_DATA_SOURCE_DND_FINISHED_SINCE_VERSION) {
-                dragSource->cancel();
-            }
+            dragSource->dndCancelled();
         }
     }
 
     if (dragTargetDevice) {
         dragTargetDevice->updateDragTarget(nullptr, serial);
     }
-    if (dragSourceDevice) {
-        auto devicePrivate = DataDeviceInterfacePrivate::get(dragSourceDevice);
-        devicePrivate->endDrag();
-    }
 
     drag = Drag();
     Q_EMIT q->dragSurfaceChanged();
@@ -491,12 +457,10 @@ void SeatInterface::notifyPointerMotion(const QPointF &pos)
         return;
     }
     if (isDragPointer()) {
-        const auto *originSurface = dragSource()->origin();
-        const bool proxyRemoteFocused = originSurface->dataProxy() && originSurface == focusedSurface;
-        if (!proxyRemoteFocused) {
-            // handled by DataDevice
+        // data device will handle it directly
+        // for xwayland cases we still want to send pointer events
+        if (!d->dataDevicesForSurface(focusedSurface).isEmpty())
             return;
-        }
     }
     if (focusedSurface->lockedPointer() && focusedSurface->lockedPointer()->isLocked()) {
         return;
@@ -532,7 +496,10 @@ void SeatInterface::setTimestamp(quint32 time)
     Q_EMIT timestampChanged(time);
 }
 
-void SeatInterface::setDragTarget(SurfaceInterface *surface, const QPointF &globalPosition, const QMatrix4x4 &inputTransformation)
+void SeatInterface::setDragTarget(AbstractDropHandler *dropTarget,
+                                  SurfaceInterface *surface,
+                                  const QPointF &globalPosition,
+                                  const QMatrix4x4 &inputTransformation)
 {
     if (surface == d->drag.surface) {
         // no change
@@ -543,20 +510,15 @@ void SeatInterface::setDragTarget(SurfaceInterface *surface, const QPointF &glob
         d->drag.target->updateDragTarget(nullptr, serial);
     }
 
-
     // TODO: technically we can have mulitple data devices
     // and we should send the drag to all of them, but that seems overly complicated
     // in practice so far the only case for mulitple data devices is for clipboard overriding
-    d->drag.target = nullptr;
-    if (d->dataDevicesForSurface(surface).size() > 0) {
-        d->drag.target = d->dataDevicesForSurface(surface).first();
-    }
+    d->drag.target = dropTarget;
 
     if (d->drag.mode == SeatInterfacePrivate::Drag::Mode::Pointer) {
         notifyPointerMotion(globalPosition);
         notifyPointerFrame();
-    } else if (d->drag.mode == SeatInterfacePrivate::Drag::Mode::Touch &&
-               d->globalTouch.focus.firstTouchPos != globalPosition) {
+    } else if (d->drag.mode == SeatInterfacePrivate::Drag::Mode::Touch && d->globalTouch.focus.firstTouchPos != globalPosition) {
         notifyTouchMotion(d->globalTouch.ids.first(), globalPosition);
     }
     if (d->drag.target) {
@@ -570,15 +532,14 @@ void SeatInterface::setDragTarget(SurfaceInterface *surface, const QPointF &glob
     return;
 }
 
-void SeatInterface::setDragTarget(SurfaceInterface *surface, const QMatrix4x4 &inputTransformation)
+void SeatInterface::setDragTarget(AbstractDropHandler *target, SurfaceInterface *surface, const QMatrix4x4 &inputTransformation)
 {
     if (d->drag.mode == SeatInterfacePrivate::Drag::Mode::Pointer) {
-        setDragTarget(surface, pointerPos(), inputTransformation);
+        setDragTarget(target, surface, pointerPos(), inputTransformation);
     } else {
         Q_ASSERT(d->drag.mode == SeatInterfacePrivate::Drag::Mode::Touch);
-        setDragTarget(surface, d->globalTouch.focus.firstTouchPos, inputTransformation);
+        setDragTarget(target, surface, d->globalTouch.focus.firstTouchPos, inputTransformation);
     }
-
 }
 
 SurfaceInterface *SeatInterface::focusedPointerSurface() const
@@ -675,11 +636,11 @@ static quint32 qtToWaylandButton(Qt::MouseButton button)
         {Qt::LeftButton, BTN_LEFT},
         {Qt::RightButton, BTN_RIGHT},
         {Qt::MiddleButton, BTN_MIDDLE},
-        {Qt::ExtraButton1, BTN_BACK},    // note: QtWayland maps BTN_SIDE
+        {Qt::ExtraButton1, BTN_BACK}, // note: QtWayland maps BTN_SIDE
         {Qt::ExtraButton2, BTN_FORWARD}, // note: QtWayland maps BTN_EXTRA
-        {Qt::ExtraButton3, BTN_TASK},    // note: QtWayland maps BTN_FORWARD
-        {Qt::ExtraButton4, BTN_EXTRA},   // note: QtWayland maps BTN_BACK
-        {Qt::ExtraButton5, BTN_SIDE},    // note: QtWayland maps BTN_TASK
+        {Qt::ExtraButton3, BTN_TASK}, // note: QtWayland maps BTN_FORWARD
+        {Qt::ExtraButton4, BTN_EXTRA}, // note: QtWayland maps BTN_BACK
+        {Qt::ExtraButton5, BTN_SIDE}, // note: QtWayland maps BTN_TASK
         {Qt::ExtraButton6, BTN_TASK + 1},
         {Qt::ExtraButton7, BTN_TASK + 2},
         {Qt::ExtraButton8, BTN_TASK + 3},
@@ -692,6 +653,7 @@ static quint32 qtToWaylandButton(Qt::MouseButton button)
     });
     return s_buttons.value(button, 0);
 #else
+    Q_UNUSED(button)
     return 0;
 #endif
 }
@@ -750,7 +712,7 @@ void SeatInterface::notifyPointerButton(quint32 button, PointerButtonState state
         d->updatePointerButtonSerial(button, serial);
         d->updatePointerButtonState(button, SeatInterfacePrivate::Pointer::State::Released);
         if (d->drag.mode == SeatInterfacePrivate::Drag::Mode::Pointer) {
-            if (d->drag.source->dragImplicitGrabSerial() != currentButtonSerial) {
+            if (d->drag.dragImplicitGrabSerial != currentButtonSerial) {
                 // not our drag button - ignore
                 return;
             }
@@ -1107,8 +1069,7 @@ void SeatInterface::notifyTouchUp(qint32 id)
     }
     Q_ASSERT(d->globalTouch.ids.contains(id));
     const qint32 serial = d->display->nextSerial();
-    if (d->drag.mode == SeatInterfacePrivate::Drag::Mode::Touch &&
-            d->drag.source->dragImplicitGrabSerial() == d->globalTouch.ids.value(id)) {
+    if (d->drag.mode == SeatInterfacePrivate::Drag::Mode::Touch && d->drag.dragImplicitGrabSerial == d->globalTouch.ids.value(id)) {
         // the implicitly grabbing touch point has been upped
         d->endDrag(serial);
     }
@@ -1182,7 +1143,7 @@ SurfaceInterface *SeatInterface::dragSurface() const
     return d->drag.surface;
 }
 
-DataDeviceInterface *SeatInterface::dragSource() const
+AbstractDataSource *SeatInterface::dragSource() const
 {
     return d->drag.source;
 }
@@ -1195,7 +1156,7 @@ void SeatInterface::setFocusedTextInputSurface(SurfaceInterface *surface)
         disconnect(d->focusedSurfaceDestroyConnection);
     }
 
-    if (d->focusedTextInputSurface != surface){
+    if (d->focusedTextInputSurface != surface) {
         d->textInputV2->d->sendLeave(serial, d->focusedTextInputSurface);
         d->textInputV3->d->sendLeave(d->focusedTextInputSurface);
         d->focusedTextInputSurface = surface;
@@ -1203,11 +1164,9 @@ void SeatInterface::setFocusedTextInputSurface(SurfaceInterface *surface)
     }
 
     if (d->focusedTextInputSurface) {
-        d->focusedSurfaceDestroyConnection = connect(surface, &SurfaceInterface::aboutToBeDestroyed, this,
-            [this] {
-                setFocusedTextInputSurface(nullptr);
-            }
-        );
+        d->focusedSurfaceDestroyConnection = connect(surface, &SurfaceInterface::aboutToBeDestroyed, this, [this] {
+            setFocusedTextInputSurface(nullptr);
+        });
     }
 
     d->textInputV2->d->sendEnter(surface, serial);
@@ -1254,7 +1213,7 @@ void SeatInterface::setSelection(AbstractDataSource *selection)
 
     d->currentSelection = selection;
 
-    for (auto focussedSelection: qAsConst(d->globalKeyboard.focus.selections)) {
+    for (auto focussedSelection : qAsConst(d->globalKeyboard.focus.selections)) {
         if (selection) {
             focussedSelection->sendSelection(selection);
         } else {
@@ -1273,6 +1232,11 @@ void SeatInterface::setSelection(AbstractDataSource *selection)
     Q_EMIT selectionChanged(selection);
 }
 
+AbstractDataSource *SeatInterface::primarySelection() const
+{
+    return d->currentPrimarySelection;
+}
+
 void SeatInterface::setPrimarySelection(AbstractDataSource *selection)
 {
     if (d->currentPrimarySelection == selection) {
@@ -1292,15 +1256,63 @@ void SeatInterface::setPrimarySelection(AbstractDataSource *selection)
 
     d->currentPrimarySelection = selection;
 
-    for (auto focussedSelection: qAsConst(d->globalKeyboard.focus.primarySelections)) {
+    for (auto focussedSelection : qAsConst(d->globalKeyboard.focus.primarySelections)) {
         if (selection) {
             focussedSelection->sendSelection(selection);
         } else {
             focussedSelection->sendClearSelection();
         }
     }
+    for (auto control : qAsConst(d->dataControlDevices)) {
+        if (selection) {
+            control->sendPrimarySelection(selection);
+        } else {
+            control->sendClearPrimarySelection();
+        }
+    }
 
     Q_EMIT primarySelectionChanged(selection);
 }
 
+void SeatInterface::startDrag(AbstractDataSource *dragSource, SurfaceInterface *originSurface, int dragSerial, DragAndDropIcon *dragIcon)
+{
+    if (hasImplicitPointerGrab(dragSerial)) {
+        d->drag.mode = SeatInterfacePrivate::Drag::Mode::Pointer;
+        d->drag.transformation = d->globalPointer.focus.transformation;
+    } else if (hasImplicitTouchGrab(dragSerial)) {
+        d->drag.mode = SeatInterfacePrivate::Drag::Mode::Touch;
+        // TODO: touch transformation
+    } else {
+        // no implicit grab, abort drag
+        return;
+    }
+    d->drag.dragImplicitGrabSerial = dragSerial;
+
+    // set initial drag target to ourself
+    d->drag.surface = originSurface;
+    // TODO: transformation needs to be either pointer or touch
+    d->drag.transformation = d->globalPointer.focus.transformation;
+
+    d->drag.source = dragSource;
+    if (dragSource) {
+        d->drag.dragSourceDestroyConnection = QObject::connect(dragSource, &AbstractDataSource::aboutToBeDestroyed, this, [this] {
+            d->cancelDrag(d->display->nextSerial());
+        });
+    }
+    d->drag.dragIcon = dragIcon;
+
+    if (!d->dataDevicesForSurface(originSurface).isEmpty()) {
+        d->drag.target = d->dataDevicesForSurface(originSurface)[0];
+    }
+    if (d->drag.target) {
+        d->drag.target->updateDragTarget(originSurface, dragSerial);
+    }
+    Q_EMIT dragStarted();
+    Q_EMIT dragSurfaceChanged();
+}
+
+DragAndDropIcon *SeatInterface::dragIcon() const
+{
+    return d->drag.dragIcon;
+}
 }
