@@ -8,17 +8,18 @@
 
 #include <KWaylandServer/kwaylandserver_export.h>
 
+#include <QMatrix4x4>
 #include <QObject>
 #include <QPoint>
-#include <QMatrix4x4>
 
 struct wl_client;
 struct wl_resource;
 
 namespace KWaylandServer
 {
-
 class AbstractDataSource;
+class AbstractDropHandler;
+class DragAndDropIcon;
 class DataDeviceInterface;
 class Display;
 class KeyboardInterface;
@@ -209,23 +210,25 @@ public:
      * @returns The DataDeviceInterface which started the drag and drop operation.
      * @see isDrag
      */
-    DataDeviceInterface *dragSource() const;
+    KWaylandServer::AbstractDataSource *dragSource() const;
     /**
      * Sets the current drag target to @p surface.
      *
      * Sends a drag leave event to the current target and an enter event to @p surface.
      * The enter position is derived from @p globalPosition and transformed by @p inputTransformation.
      */
-    void setDragTarget(SurfaceInterface *surface, const QPointF &globalPosition, const QMatrix4x4 &inputTransformation);
+    void setDragTarget(AbstractDropHandler *dropTarget, SurfaceInterface *surface, const QPointF &globalPosition, const QMatrix4x4 &inputTransformation);
     /**
      * Sets the current drag target to @p surface.
      *
      * Sends a drag leave event to the current target and an enter event to @p surface.
      * The enter position is derived from current global position and transformed by @p inputTransformation.
      */
-    void setDragTarget(SurfaceInterface *surface, const QMatrix4x4 &inputTransformation = QMatrix4x4());
+    void setDragTarget(AbstractDropHandler *dropTarget, SurfaceInterface *surface, const QMatrix4x4 &inputTransformation = QMatrix4x4());
     ///@}
 
+    AbstractDropHandler *dropHandlerForSurface(SurfaceInterface *surface) const;
+
     /**
      * @name Pointer related methods
      */
@@ -590,7 +593,7 @@ public:
      * @see focusedTextInputSurface
      */
     TextInputV2Interface *textInputV2() const;
-    
+
     TextInputV3Interface *textInputV3() const;
     ///@}
 
@@ -616,12 +619,21 @@ public:
      */
     void setSelection(AbstractDataSource *selection);
 
+    KWaylandServer::AbstractDataSource *primarySelection() const;
     void setPrimarySelection(AbstractDataSource *selection);
 
+    void startDrag(AbstractDataSource *source, SurfaceInterface *sourceSurface, int dragSerial = -1, DragAndDropIcon *dragIcon = nullptr);
+
+    /**
+     * Returns the additional icon attached to the cursor during a drag-and-drop operation.
+     * This function returns @c null if no drag-and-drop is active or no icon has been attached.
+     */
+    DragAndDropIcon *dragIcon() const;
+
     static SeatInterface *get(wl_resource *native);
 
 Q_SIGNALS:
-    void nameChanged(const QString&);
+    void nameChanged(const QString &);
     void hasPointerChanged(bool);
     void hasKeyboardChanged(bool);
     void hasTouchChanged(bool);
@@ -634,13 +646,13 @@ Q_SIGNALS:
      * @see selection
      * @see setSelection
      */
-    void selectionChanged(KWaylandServer::AbstractDataSource*);
+    void selectionChanged(KWaylandServer::AbstractDataSource *);
 
     /**
      * Emitted whenever the primary selection changes
      * @see primarySelection
      */
-    void primarySelectionChanged(KWaylandServer::AbstractDataSource*);
+    void primarySelectionChanged(KWaylandServer::AbstractDataSource *);
 
     /**
      * Emitted when a drag'n'drop operation is started
@@ -675,4 +687,4 @@ private:
 
 }
 
-Q_DECLARE_METATYPE(KWaylandServer::SeatInterface*)
+Q_DECLARE_METATYPE(KWaylandServer::SeatInterface *)
