@@ -16,69 +16,66 @@
 
 namespace KWaylandServer
 {
-
 class IdleInhibitorV1Interface;
 class SurfaceRole;
 class ViewportInterface;
 
-class KWaylandFrameCallback : public QtWaylandServer::wl_callback
-{
-public:
-    KWaylandFrameCallback(wl_resource *resource, SurfaceInterface *surface);
+struct SurfaceState {
+    void mergeInto(SurfaceState *target);
 
-    void destroy();
+    QRegion damage = QRegion();
+    QRegion bufferDamage = QRegion();
+    QRegion opaque = QRegion();
+    QRegion input = infiniteRegion();
+    bool inputIsSet = false;
+    bool opaqueIsSet = false;
+    bool bufferIsSet = false;
+    bool shadowIsSet = false;
+    bool blurIsSet = false;
+    bool contrastIsSet = false;
+    bool slideIsSet = false;
+    bool childrenChanged = false;
+    bool bufferScaleIsSet = false;
+    bool bufferTransformIsSet = false;
+    qint32 bufferScale = 1;
+    OutputInterface::Transform bufferTransform = OutputInterface::Transform::Normal;
+    wl_list frameCallbacks;
+    QPoint offset = QPoint();
+    QPointer<ClientBuffer> buffer;
+    QPointer<ShadowInterface> shadow;
+    QPointer<BlurInterface> blur;
+    QPointer<ContrastInterface> contrast;
+    QPointer<SlideInterface> slide;
 
-    QPointer<SurfaceInterface> surface;
+    // Subsurfaces are stored in two lists. The below list contains subsurfaces that
+    // are below their parent surface; the above list contains subsurfaces that are
+    // placed above the parent surface.
+    QList<SubSurfaceInterface *> below;
+    QList<SubSurfaceInterface *> above;
 
-protected:
-    void callback_destroy_resource(Resource *resource) override;
+    struct {
+        QRectF sourceGeometry = QRectF();
+        QSize destinationSize = QSize();
+        bool sourceGeometryIsSet = false;
+        bool destinationSizeIsSet = false;
+    } viewport;
 };
 
 class SurfaceInterfacePrivate : public QtWaylandServer::wl_surface
 {
 public:
-    struct State {
-        QRegion damage = QRegion();
-        QRegion bufferDamage = QRegion();
-        QRegion opaque = QRegion();
-        QRegion input = infiniteRegion();
-        QRectF sourceGeometry = QRectF();
-        QSize destinationSize = QSize();
-        QSize size = QSize();
-        bool sourceGeometryIsSet = false;
-        bool destinationSizeIsSet = false;
-        bool inputIsSet = false;
-        bool opaqueIsSet = false;
-        bool bufferIsSet = false;
-        bool shadowIsSet = false;
-        bool blurIsSet = false;
-        bool contrastIsSet = false;
-        bool slideIsSet = false;
-        bool childrenChanged = false;
-        bool bufferScaleIsSet = false;
-        bool bufferTransformIsSet = false;
-        qint32 bufferScale = 1;
-        OutputInterface::Transform bufferTransform = OutputInterface::Transform::Normal;
-        QList<KWaylandFrameCallback *> frameCallbacks;
-        QPoint offset = QPoint();
-        BufferInterface *buffer = nullptr;
-        // stacking order: bottom (first) -> top (last)
-        QList<SubSurfaceInterface *> children;
-        QPointer<ShadowInterface> shadow;
-        QPointer<BlurInterface> blur;
-        QPointer<ContrastInterface> contrast;
-        QPointer<SlideInterface> slide;
-    };
-
-    static SurfaceInterfacePrivate *get(SurfaceInterface *surface) { return surface->d.data(); }
+    static SurfaceInterfacePrivate *get(SurfaceInterface *surface)
+    {
+        return surface->d.data();
+    }
 
     explicit SurfaceInterfacePrivate(SurfaceInterface *q);
     ~SurfaceInterfacePrivate() override;
 
     void addChild(SubSurfaceInterface *subsurface);
     void removeChild(SubSurfaceInterface *subsurface);
-    bool raiseChild(SubSurfaceInterface *subsurface, SurfaceInterface *sibling);
-    bool lowerChild(SubSurfaceInterface *subsurface, SurfaceInterface *sibling);
+    bool raiseChild(SubSurfaceInterface *subsurface, SurfaceInterface *anchor);
+    bool lowerChild(SubSurfaceInterface *subsurface, SurfaceInterface *anchor);
     void setShadow(const QPointer<ShadowInterface> &shadow);
     void setBlur(const QPointer<BlurInterface> &blur);
     void setContrast(const QPointer<ContrastInterface> &contrast);
@@ -90,44 +87,38 @@ public:
     void commitToCache();
     void commitFromCache();
 
-    void commit();
     void commitSubSurface();
-    QMatrix4x4 buildSurfaceToBufferMatrix(const State *state);
-    void swapStates(State *source, State *target, bool emitChanged);
+    QMatrix4x4 buildSurfaceToBufferMatrix();
+    void applyState(SurfaceState *next);
+
+    bool computeEffectiveMapped() const;
+    void updateEffectiveMapped();
 
     CompositorInterface *compositor;
     SurfaceInterface *q;
     SurfaceRole *role = nullptr;
-
-    State current;
-    State pending;
-    State cached;
+    SurfaceState current;
+    SurfaceState pending;
+    SurfaceState cached;
     SubSurfaceInterface *subSurface = nullptr;
     QMatrix4x4 surfaceToBufferMatrix;
     QMatrix4x4 bufferToSurfaceMatrix;
     QSize bufferSize;
+    QSize surfaceSize;
     QRegion inputRegion;
+    ClientBuffer *bufferRef = nullptr;
+    bool mapped = false;
     bool hasCacheState = false;
 
-    // workaround for https://bugreports.qt.io/browse/QTBUG-52192
-    // A subsurface needs to be considered mapped even if it doesn't have a buffer attached
-    // Otherwise Qt's sub-surfaces will never be visible and the client will freeze due to
-    // waiting on the frame callback of the never visible surface
-    bool subSurfaceIsMapped = true;
-
     QVector<OutputInterface *> outputs;
 
     LockedPointerV1Interface *lockedPointer = nullptr;
     ConfinedPointerV1Interface *confinedPointer = nullptr;
-    QHash<OutputInterface*, QMetaObject::Connection> outputDestroyedConnections;
-    QHash<OutputInterface*, QMetaObject::Connection> outputBoundConnections;
+    QHash<OutputInterface *, QMetaObject::Connection> outputDestroyedConnections;
+    QHash<OutputInterface *, QMetaObject::Connection> outputBoundConnections;
 
-    QVector<IdleInhibitorV1Interface*> idleInhibitors;
+    QVector<IdleInhibitorV1Interface *> idleInhibitors;
     ViewportInterface *viewportExtension = nullptr;
-    SurfaceInterface *dataProxy = nullptr;
-
-    static QList<SurfaceInterface *> surfaces;
-
     ClientConnection *client = nullptr;
 
 protected:
