@@ -3,7 +3,6 @@
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
-#include "../src/server/buffer_interface.h"
 #include "../src/server/compositor_interface.h"
 #include "../src/server/datadevicemanager_interface.h"
 #include "../src/server/display.h"
@@ -11,6 +10,7 @@
 #include "../src/server/output_interface.h"
 #include "../src/server/pointer_interface.h"
 #include "../src/server/seat_interface.h"
+#include "../src/server/shmclientbuffer.h"
 #include "../src/server/xdgshell_interface.h"
 
 #include <QApplication>
@@ -22,17 +22,15 @@
 #include <QWidget>
 #include <QtConcurrent>
 
-#include <unistd.h>
 #include <iostream>
+#include <unistd.h>
 
 static int startXServer()
 {
     const QByteArray process = QByteArrayLiteral("Xwayland");
     int pipeFds[2];
     if (pipe(pipeFds) != 0) {
-        std::cerr << "FATAL ERROR failed to create pipe to start X Server "
-                  << process.constData()
-                  << std::endl;
+        std::cerr << "FATAL ERROR failed to create pipe to start X Server " << process.constData() << std::endl;
         exit(1);
     }
 
@@ -63,7 +61,7 @@ static void readDisplayFromPipe(int pipe)
     QByteArray displayNumber = readPipe.readLine();
 
     displayNumber.prepend(QByteArray(":"));
-    displayNumber.remove(displayNumber.size() -1, 1);
+    displayNumber.remove(displayNumber.size() - 1, 1);
     std::cout << "X-Server started on display " << displayNumber.constData() << std::endl;
 
     setenv("DISPLAY", displayNumber.constData(), true);
@@ -112,13 +110,11 @@ void CompositorWindow::surfaceCreated(KWaylandServer::XdgToplevelInterface *surf
     surface->sendConfigure(QSize(), XdgToplevelInterface::States());
     m_stackingOrder << surface;
     connect(surface->surface(), &SurfaceInterface::damaged, this, static_cast<void (CompositorWindow::*)()>(&CompositorWindow::update));
-    connect(surface, &XdgToplevelInterface::destroyed, this,
-        [surface, this] {
-            m_stackingOrder.removeAll(surface);
-            updateFocus();
-            update();
-        }
-    );
+    connect(surface, &XdgToplevelInterface::destroyed, this, [surface, this] {
+        m_stackingOrder.removeAll(surface);
+        updateFocus();
+        update();
+    });
     updateFocus();
 }
 
@@ -128,11 +124,9 @@ void CompositorWindow::updateFocus()
     if (!m_seat || m_stackingOrder.isEmpty()) {
         return;
     }
-    auto it = std::find_if(m_stackingOrder.constBegin(), m_stackingOrder.constEnd(),
-        [](XdgToplevelInterface *toplevel) {
-            return toplevel->surface()->isMapped();
-        }
-    );
+    auto it = std::find_if(m_stackingOrder.constBegin(), m_stackingOrder.constEnd(), [](XdgToplevelInterface *toplevel) {
+        return toplevel->surface()->isMapped();
+    });
     if (it == m_stackingOrder.constEnd()) {
         return;
     }
@@ -140,7 +134,7 @@ void CompositorWindow::updateFocus()
     m_seat->setFocusedKeyboardSurface((*it)->surface());
 }
 
-void CompositorWindow::setSeat(const QPointer< KWaylandServer::SeatInterface > &seat)
+void CompositorWindow::setSeat(const QPointer<KWaylandServer::SeatInterface> &seat)
 {
     m_seat = seat;
 }
@@ -154,8 +148,10 @@ void CompositorWindow::paintEvent(QPaintEvent *event)
         if (!surface || !surface->isMapped()) {
             continue;
         }
-        KWaylandServer::BufferInterface *buffer = surface->buffer();
-        p.drawImage(QPoint(0, 0), buffer->data());
+        auto clientBuffer = qobject_cast<KWaylandServer::ShmClientBuffer *>(surface->buffer());
+        if (clientBuffer) {
+            p.drawImage(QPoint(0, 0), clientBuffer->data());
+        }
         surface->frameRendered(QDateTime::currentMSecsSinceEpoch());
     }
 }
@@ -236,8 +232,7 @@ int main(int argc, char **argv)
 
     QCommandLineParser parser;
     parser.addHelpOption();
-    QCommandLineOption xwaylandOption(QStringList{QStringLiteral("x"), QStringLiteral("xwayland")},
-                                      QStringLiteral("Start a rootless Xwayland server"));
+    QCommandLineOption xwaylandOption(QStringList{QStringLiteral("x"), QStringLiteral("xwayland")}, QStringLiteral("Start a rootless Xwayland server"));
     parser.addOption(xwaylandOption);
     parser.process(app);
 
@@ -272,7 +267,9 @@ int main(int argc, char **argv)
             exit(1);
         }
 
-        QtConcurrent::run([pipe] { readDisplayFromPipe(pipe); });
+        QtConcurrent::run([pipe] {
+            readDisplayFromPipe(pipe);
+        });
     }
 
     return app.exec();
